# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tron_sdk_py/proto/api/zksnark.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'tron_sdk_py/proto/api/zksnark.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tron_sdk_py.proto.core import Tron_pb2 as tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#tron_sdk_py/proto/api/zksnark.proto\x12\x08protocol\x1a!tron_sdk_py/proto/core/Tron.proto\"q\n\x0eZksnarkRequest\x12*\n\x0btransaction\x18\x01 \x01(\x0b\x32\x15.protocol.Transaction\x12\x0f\n\x07sighash\x18\x02 \x01(\x0c\x12\x14\n\x0cvalueBalance\x18\x03 \x01(\x03\x12\x0c\n\x04txId\x18\x04 \x01(\t\"`\n\x0fZksnarkResponse\x12,\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x1e.protocol.ZksnarkResponse.Code\"\x1f\n\x04\x43ode\x12\x0b\n\x07SUCCESS\x10\x00\x12\n\n\x06\x46\x41ILED\x10\x01\x32Y\n\x0bTronZksnark\x12J\n\x11\x43heckZksnarkProof\x12\x18.protocol.ZksnarkRequest\x1a\x19.protocol.ZksnarkResponse\"\x00\x42H\n\x0corg.tron.apiB\x0eZksnarkGrpcAPIZ(github.com/tronprotocol/grpc-gateway/apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tron_sdk_py.proto.api.zksnark_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014org.tron.apiB\016ZksnarkGrpcAPIZ(github.com/tronprotocol/grpc-gateway/api'
  _globals['_ZKSNARKREQUEST']._serialized_start=84
  _globals['_ZKSNARKREQUEST']._serialized_end=197
  _globals['_ZKSNARKRESPONSE']._serialized_start=199
  _globals['_ZKSNARKRESPONSE']._serialized_end=295
  _globals['_ZKSNARKRESPONSE_CODE']._serialized_start=264
  _globals['_ZKSNARKRESPONSE_CODE']._serialized_end=295
  _globals['_TRONZKSNARK']._serialized_start=297
  _globals['_TRONZKSNARK']._serialized_end=386
# @@protoc_insertion_point(module_scope)
