# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tron_sdk_py/proto/api/api.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'tron_sdk_py/proto/api/api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tron_sdk_py.proto.core import Tron_pb2 as tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from tron_sdk_py.proto.core.contract import asset_issue_contract_pb2 as tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2
from tron_sdk_py.proto.core.contract import account_contract_pb2 as tron__sdk__py_dot_proto_dot_core_dot_contract_dot_account__contract__pb2
from tron_sdk_py.proto.core.contract import witness_contract_pb2 as tron__sdk__py_dot_proto_dot_core_dot_contract_dot_witness__contract__pb2
from tron_sdk_py.proto.core.contract import balance_contract_pb2 as tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2
from tron_sdk_py.proto.core.contract import proposal_contract_pb2 as tron__sdk__py_dot_proto_dot_core_dot_contract_dot_proposal__contract__pb2
from tron_sdk_py.proto.core.contract import storage_contract_pb2 as tron__sdk__py_dot_proto_dot_core_dot_contract_dot_storage__contract__pb2
from tron_sdk_py.proto.core.contract import exchange_contract_pb2 as tron__sdk__py_dot_proto_dot_core_dot_contract_dot_exchange__contract__pb2
from tron_sdk_py.proto.core.contract import market_contract_pb2 as tron__sdk__py_dot_proto_dot_core_dot_contract_dot_market__contract__pb2
from tron_sdk_py.proto.core.contract import smart_contract_pb2 as tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2
from tron_sdk_py.proto.core.contract import shield_contract_pb2 as tron__sdk__py_dot_proto_dot_core_dot_contract_dot_shield__contract__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ftron_sdk_py/proto/api/api.proto\x12\x08protocol\x1a!tron_sdk_py/proto/core/Tron.proto\x1a\x1cgoogle/api/annotations.proto\x1a:tron_sdk_py/proto/core/contract/asset_issue_contract.proto\x1a\x36tron_sdk_py/proto/core/contract/account_contract.proto\x1a\x36tron_sdk_py/proto/core/contract/witness_contract.proto\x1a\x36tron_sdk_py/proto/core/contract/balance_contract.proto\x1a\x37tron_sdk_py/proto/core/contract/proposal_contract.proto\x1a\x36tron_sdk_py/proto/core/contract/storage_contract.proto\x1a\x37tron_sdk_py/proto/core/contract/exchange_contract.proto\x1a\x35tron_sdk_py/proto/core/contract/market_contract.proto\x1a\x34tron_sdk_py/proto/core/contract/smart_contract.proto\x1a\x35tron_sdk_py/proto/core/contract/shield_contract.proto\"\xac\x03\n\x06Return\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12,\n\x04\x63ode\x18\x02 \x01(\x0e\x32\x1e.protocol.Return.response_code\x12\x0f\n\x07message\x18\x03 \x01(\x0c\"\xd2\x02\n\rresponse_code\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0c\n\x08SIGERROR\x10\x01\x12\x1b\n\x17\x43ONTRACT_VALIDATE_ERROR\x10\x02\x12\x16\n\x12\x43ONTRACT_EXE_ERROR\x10\x03\x12\x12\n\x0e\x42\x41NDWITH_ERROR\x10\x04\x12\x19\n\x15\x44UP_TRANSACTION_ERROR\x10\x05\x12\x0f\n\x0bTAPOS_ERROR\x10\x06\x12\x1d\n\x19TOO_BIG_TRANSACTION_ERROR\x10\x07\x12 \n\x1cTRANSACTION_EXPIRATION_ERROR\x10\x08\x12\x0f\n\x0bSERVER_BUSY\x10\t\x12\x11\n\rNO_CONNECTION\x10\n\x12#\n\x1fNOT_ENOUGH_EFFECTIVE_CONNECTION\x10\x0b\x12\x16\n\x12\x42LOCK_UNSOLIDIFIED\x10\x0c\x12\x0f\n\x0bOTHER_ERROR\x10\x14\"7\n\x0e\x42lockReference\x12\x11\n\tblock_num\x18\x01 \x01(\x03\x12\x12\n\nblock_hash\x18\x02 \x01(\x0c\"3\n\x0bWitnessList\x12$\n\twitnesses\x18\x01 \x03(\x0b\x32\x11.protocol.Witness\"5\n\x0cProposalList\x12%\n\tproposals\x18\x01 \x03(\x0b\x32\x12.protocol.Proposal\"5\n\x0c\x45xchangeList\x12%\n\texchanges\x18\x01 \x03(\x0b\x32\x12.protocol.Exchange\"B\n\x0e\x41ssetIssueList\x12\x30\n\nassetIssue\x18\x01 \x03(\x0b\x32\x1c.protocol.AssetIssueContract\"+\n\tBlockList\x12\x1e\n\x05\x62lock\x18\x01 \x03(\x0b\x32\x0f.protocol.Block\"=\n\x0fTransactionList\x12*\n\x0btransaction\x18\x01 \x03(\x0b\x32\x15.protocol.Transaction\"!\n\x11TransactionIdList\x12\x0c\n\x04txId\x18\x01 \x03(\t\"B\n\x18\x44\x65legatedResourceMessage\x12\x13\n\x0b\x66romAddress\x18\x01 \x01(\x0c\x12\x11\n\ttoAddress\x18\x02 \x01(\x0c\"O\n\x15\x44\x65legatedResourceList\x12\x36\n\x11\x64\x65legatedResource\x18\x01 \x03(\x0b\x32\x1b.protocol.DelegatedResource\"@\n\'GetAvailableUnfreezeCountRequestMessage\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\"9\n(GetAvailableUnfreezeCountResponseMessage\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\"H\n!CanDelegatedMaxSizeRequestMessage\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x15\n\rowner_address\x18\x02 \x01(\x0c\"6\n\"CanDelegatedMaxSizeResponseMessage\x12\x10\n\x08max_size\x18\x01 \x01(\x03\"S\n\'CanWithdrawUnfreezeAmountRequestMessage\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\":\n(CanWithdrawUnfreezeAmountResponseMessage\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x03\"\'\n\x15PricesResponseMessage\x12\x0e\n\x06prices\x18\x01 \x01(\t\")\n\x08NodeList\x12\x1d\n\x05nodes\x18\x01 \x03(\x0b\x32\x0e.protocol.Node\"*\n\x04Node\x12\"\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x11.protocol.Address\"%\n\x07\x41\x64\x64ress\x12\x0c\n\x04host\x18\x01 \x01(\x0c\x12\x0c\n\x04port\x18\x02 \x01(\x05\"\x0e\n\x0c\x45mptyMessage\"\x1c\n\rNumberMessage\x12\x0b\n\x03num\x18\x01 \x01(\x03\"\x1d\n\x0c\x42ytesMessage\x12\r\n\x05value\x18\x01 \x01(\x0c\"E\n\x0bTimeMessage\x12\x1b\n\x13\x62\x65ginInMilliseconds\x18\x01 \x01(\x03\x12\x19\n\x11\x65ndInMilliseconds\x18\x02 \x01(\x03\"-\n\x08\x42lockReq\x12\x11\n\tid_or_num\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65tail\x18\x02 \x01(\x08\".\n\nBlockLimit\x12\x10\n\x08startNum\x18\x01 \x01(\x03\x12\x0e\n\x06\x65ndNum\x18\x02 \x01(\x03\";\n\x10TransactionLimit\x12\x15\n\rtransactionId\x18\x01 \x01(\x0c\x12\x10\n\x08limitNum\x18\x02 \x01(\x03\"U\n\x10\x41\x63\x63ountPaginated\x12\"\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x11.protocol.Account\x12\x0e\n\x06offset\x18\x02 \x01(\x03\x12\r\n\x05limit\x18\x03 \x01(\x03\"a\n\x14TimePaginatedMessage\x12*\n\x0btimeMessage\x18\x01 \x01(\x0b\x32\x15.protocol.TimeMessage\x12\x0e\n\x06offset\x18\x02 \x01(\x03\x12\r\n\x05limit\x18\x03 \x01(\x03\"\x87\x03\n\x11\x41\x63\x63ountNetMessage\x12\x13\n\x0b\x66reeNetUsed\x18\x01 \x01(\x03\x12\x14\n\x0c\x66reeNetLimit\x18\x02 \x01(\x03\x12\x0f\n\x07NetUsed\x18\x03 \x01(\x03\x12\x10\n\x08NetLimit\x18\x04 \x01(\x03\x12\x43\n\x0c\x61ssetNetUsed\x18\x05 \x03(\x0b\x32-.protocol.AccountNetMessage.AssetNetUsedEntry\x12\x45\n\rassetNetLimit\x18\x06 \x03(\x0b\x32..protocol.AccountNetMessage.AssetNetLimitEntry\x12\x15\n\rTotalNetLimit\x18\x07 \x01(\x03\x12\x16\n\x0eTotalNetWeight\x18\x08 \x01(\x03\x1a\x33\n\x11\x41ssetNetUsedEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x34\n\x12\x41ssetNetLimitEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\xec\x04\n\x16\x41\x63\x63ountResourceMessage\x12\x13\n\x0b\x66reeNetUsed\x18\x01 \x01(\x03\x12\x14\n\x0c\x66reeNetLimit\x18\x02 \x01(\x03\x12\x0f\n\x07NetUsed\x18\x03 \x01(\x03\x12\x10\n\x08NetLimit\x18\x04 \x01(\x03\x12H\n\x0c\x61ssetNetUsed\x18\x05 \x03(\x0b\x32\x32.protocol.AccountResourceMessage.AssetNetUsedEntry\x12J\n\rassetNetLimit\x18\x06 \x03(\x0b\x32\x33.protocol.AccountResourceMessage.AssetNetLimitEntry\x12\x15\n\rTotalNetLimit\x18\x07 \x01(\x03\x12\x16\n\x0eTotalNetWeight\x18\x08 \x01(\x03\x12\x1c\n\x14TotalTronPowerWeight\x18\t \x01(\x03\x12\x15\n\rtronPowerUsed\x18\n \x01(\x03\x12\x16\n\x0etronPowerLimit\x18\x0b \x01(\x03\x12\x12\n\nEnergyUsed\x18\r \x01(\x03\x12\x13\n\x0b\x45nergyLimit\x18\x0e \x01(\x03\x12\x18\n\x10TotalEnergyLimit\x18\x0f \x01(\x03\x12\x19\n\x11TotalEnergyWeight\x18\x10 \x01(\x03\x12\x13\n\x0bstorageUsed\x18\x15 \x01(\x03\x12\x14\n\x0cstorageLimit\x18\x16 \x01(\x03\x1a\x33\n\x11\x41ssetNetUsedEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x34\n\x12\x41ssetNetLimitEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"1\n\x10PaginatedMessage\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\r\n\x05limit\x18\x02 \x01(\x03\"\xa3\x02\n\x14TransactionExtention\x12*\n\x0btransaction\x18\x01 \x01(\x0b\x32\x15.protocol.Transaction\x12\x0c\n\x04txid\x18\x02 \x01(\x0c\x12\x17\n\x0f\x63onstant_result\x18\x03 \x03(\x0c\x12 \n\x06result\x18\x04 \x01(\x0b\x32\x10.protocol.Return\x12\x13\n\x0b\x65nergy_used\x18\x05 \x01(\x03\x12+\n\x04logs\x18\x06 \x03(\x0b\x32\x1d.protocol.TransactionInfo.Log\x12<\n\x15internal_transactions\x18\x07 \x03(\x0b\x32\x1d.protocol.InternalTransaction\x12\x16\n\x0e\x65nergy_penalty\x18\x08 \x01(\x03\"R\n\x15\x45stimateEnergyMessage\x12 \n\x06result\x18\x01 \x01(\x0b\x32\x10.protocol.Return\x12\x17\n\x0f\x65nergy_required\x18\x02 \x01(\x03\"\x84\x01\n\x0e\x42lockExtention\x12\x34\n\x0ctransactions\x18\x01 \x03(\x0b\x32\x1e.protocol.TransactionExtention\x12+\n\x0c\x62lock_header\x18\x02 \x01(\x0b\x32\x15.protocol.BlockHeader\x12\x0f\n\x07\x62lockid\x18\x03 \x01(\x0c\"=\n\x12\x42lockListExtention\x12\'\n\x05\x62lock\x18\x01 \x03(\x0b\x32\x18.protocol.BlockExtention\"O\n\x18TransactionListExtention\x12\x33\n\x0btransaction\x18\x01 \x03(\x0b\x32\x1e.protocol.TransactionExtention\"a\n\x1a\x42lockIncrementalMerkleTree\x12\x0e\n\x06number\x18\x01 \x01(\x03\x12\x33\n\nmerkleTree\x18\x02 \x01(\x0b\x32\x1f.protocol.IncrementalMerkleTree\"\xdf\x03\n\x15TransactionSignWeight\x12(\n\npermission\x18\x01 \x01(\x0b\x32\x14.protocol.Permission\x12\x15\n\rapproved_list\x18\x02 \x03(\x0c\x12\x16\n\x0e\x63urrent_weight\x18\x03 \x01(\x03\x12\x36\n\x06result\x18\x04 \x01(\x0b\x32&.protocol.TransactionSignWeight.Result\x12\x33\n\x0btransaction\x18\x05 \x01(\x0b\x32\x1e.protocol.TransactionExtention\x1a\xff\x01\n\x06Result\x12\x42\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x34.protocol.TransactionSignWeight.Result.response_code\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x9f\x01\n\rresponse_code\x12\x15\n\x11\x45NOUGH_PERMISSION\x10\x00\x12\x19\n\x15NOT_ENOUGH_PERMISSION\x10\x01\x12\x1a\n\x16SIGNATURE_FORMAT_ERROR\x10\x02\x12\x19\n\x15\x43OMPUTE_ADDRESS_ERROR\x10\x03\x12\x14\n\x10PERMISSION_ERROR\x10\x04\x12\x0f\n\x0bOTHER_ERROR\x10\x14\"\xe7\x02\n\x17TransactionApprovedList\x12\x15\n\rapproved_list\x18\x02 \x03(\x0c\x12\x38\n\x06result\x18\x04 \x01(\x0b\x32(.protocol.TransactionApprovedList.Result\x12\x33\n\x0btransaction\x18\x05 \x01(\x0b\x32\x1e.protocol.TransactionExtention\x1a\xc5\x01\n\x06Result\x12\x44\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x36.protocol.TransactionApprovedList.Result.response_code\x12\x0f\n\x07message\x18\x02 \x01(\t\"d\n\rresponse_code\x12\x0b\n\x07SUCCESS\x10\x00\x12\x1a\n\x16SIGNATURE_FORMAT_ERROR\x10\x01\x12\x19\n\x15\x43OMPUTE_ADDRESS_ERROR\x10\x02\x12\x0f\n\x0bOTHER_ERROR\x10\x14\"W\n\x14IvkDecryptParameters\x12\x19\n\x11start_block_index\x18\x01 \x01(\x03\x12\x17\n\x0f\x65nd_block_index\x18\x02 \x01(\x03\x12\x0b\n\x03ivk\x18\x03 \x01(\x0c\"v\n\x1bIvkDecryptAndMarkParameters\x12\x19\n\x11start_block_index\x18\x01 \x01(\x03\x12\x17\n\x0f\x65nd_block_index\x18\x02 \x01(\x03\x12\x0b\n\x03ivk\x18\x05 \x01(\x0c\x12\n\n\x02\x61k\x18\x03 \x01(\x0c\x12\n\n\x02nk\x18\x04 \x01(\x0c\"W\n\x14OvkDecryptParameters\x12\x19\n\x11start_block_index\x18\x01 \x01(\x03\x12\x17\n\x0f\x65nd_block_index\x18\x02 \x01(\x03\x12\x0b\n\x03ovk\x18\x03 \x01(\x0c\"\x83\x01\n\x0c\x44\x65\x63ryptNotes\x12.\n\x07noteTxs\x18\x01 \x03(\x0b\x32\x1d.protocol.DecryptNotes.NoteTx\x1a\x43\n\x06NoteTx\x12\x1c\n\x04note\x18\x01 \x01(\x0b\x32\x0e.protocol.Note\x12\x0c\n\x04txid\x18\x02 \x01(\x0c\x12\r\n\x05index\x18\x03 \x01(\x05\"\xa1\x01\n\x12\x44\x65\x63ryptNotesMarked\x12\x34\n\x07noteTxs\x18\x01 \x03(\x0b\x32#.protocol.DecryptNotesMarked.NoteTx\x1aU\n\x06NoteTx\x12\x1c\n\x04note\x18\x01 \x01(\x0b\x32\x0e.protocol.Note\x12\x0c\n\x04txid\x18\x02 \x01(\x0c\x12\r\n\x05index\x18\x03 \x01(\x05\x12\x10\n\x08is_spend\x18\x04 \x01(\x08\"I\n\x04Note\x12\r\n\x05value\x18\x01 \x01(\x03\x12\x17\n\x0fpayment_address\x18\x02 \x01(\t\x12\x0b\n\x03rcm\x18\x03 \x01(\x0c\x12\x0c\n\x04memo\x18\x04 \x01(\x0c\"{\n\tSpendNote\x12\x1c\n\x04note\x18\x03 \x01(\x0b\x32\x0e.protocol.Note\x12\r\n\x05\x61lpha\x18\x04 \x01(\x0c\x12\x33\n\x07voucher\x18\x05 \x01(\x0b\x32\".protocol.IncrementalMerkleVoucher\x12\x0c\n\x04path\x18\x06 \x01(\x0c\"+\n\x0bReceiveNote\x12\x1c\n\x04note\x18\x01 \x01(\x0b\x32\x0e.protocol.Note\"\x95\x02\n\x11PrivateParameters\x12 \n\x18transparent_from_address\x18\x01 \x01(\x0c\x12\x0b\n\x03\x61sk\x18\x02 \x01(\x0c\x12\x0b\n\x03nsk\x18\x03 \x01(\x0c\x12\x0b\n\x03ovk\x18\x04 \x01(\x0c\x12\x13\n\x0b\x66rom_amount\x18\x05 \x01(\x03\x12,\n\x0fshielded_spends\x18\x06 \x03(\x0b\x32\x13.protocol.SpendNote\x12\x30\n\x11shielded_receives\x18\x07 \x03(\x0b\x32\x15.protocol.ReceiveNote\x12\x1e\n\x16transparent_to_address\x18\x08 \x01(\x0c\x12\x11\n\tto_amount\x18\t \x01(\x03\x12\x0f\n\x07timeout\x18\n \x01(\x03\"\x9e\x02\n\x1bPrivateParametersWithoutAsk\x12 \n\x18transparent_from_address\x18\x01 \x01(\x0c\x12\n\n\x02\x61k\x18\x02 \x01(\x0c\x12\x0b\n\x03nsk\x18\x03 \x01(\x0c\x12\x0b\n\x03ovk\x18\x04 \x01(\x0c\x12\x13\n\x0b\x66rom_amount\x18\x05 \x01(\x03\x12,\n\x0fshielded_spends\x18\x06 \x03(\x0b\x32\x13.protocol.SpendNote\x12\x30\n\x11shielded_receives\x18\x07 \x03(\x0b\x32\x15.protocol.ReceiveNote\x12\x1e\n\x16transparent_to_address\x18\x08 \x01(\x0c\x12\x11\n\tto_amount\x18\t \x01(\x03\x12\x0f\n\x07timeout\x18\n \x01(\x03\"E\n\x16SpendAuthSigParameters\x12\x0b\n\x03\x61sk\x18\x01 \x01(\x0c\x12\x0f\n\x07tx_hash\x18\x02 \x01(\x0c\x12\r\n\x05\x61lpha\x18\x03 \x01(\x0c\"y\n\x0cNfParameters\x12\x1c\n\x04note\x18\x01 \x01(\x0b\x32\x0e.protocol.Note\x12\x33\n\x07voucher\x18\x02 \x01(\x0b\x32\".protocol.IncrementalMerkleVoucher\x12\n\n\x02\x61k\x18\x03 \x01(\x0c\x12\n\n\x02nk\x18\x04 \x01(\x0c\"C\n\x1a\x45xpandedSpendingKeyMessage\x12\x0b\n\x03\x61sk\x18\x01 \x01(\x0c\x12\x0b\n\x03nsk\x18\x02 \x01(\x0c\x12\x0b\n\x03ovk\x18\x03 \x01(\x0c\"+\n\x11ViewingKeyMessage\x12\n\n\x02\x61k\x18\x01 \x01(\x0c\x12\n\n\x02nk\x18\x02 \x01(\x0c\"(\n\x19IncomingViewingKeyMessage\x12\x0b\n\x03ivk\x18\x01 \x01(\x0c\"\x1f\n\x12\x44iversifierMessage\x12\t\n\x01\x64\x18\x01 \x01(\x0c\"\x81\x01\n$IncomingViewingKeyDiversifierMessage\x12\x30\n\x03ivk\x18\x01 \x01(\x0b\x32#.protocol.IncomingViewingKeyMessage\x12\'\n\x01\x64\x18\x02 \x01(\x0b\x32\x1c.protocol.DiversifierMessage\"f\n\x15PaymentAddressMessage\x12\'\n\x01\x64\x18\x01 \x01(\x0b\x32\x1c.protocol.DiversifierMessage\x12\x0b\n\x03pkD\x18\x02 \x01(\x0c\x12\x17\n\x0fpayment_address\x18\x03 \x01(\t\"\x9e\x01\n\x13ShieldedAddressInfo\x12\n\n\x02sk\x18\x01 \x01(\x0c\x12\x0b\n\x03\x61sk\x18\x02 \x01(\x0c\x12\x0b\n\x03nsk\x18\x03 \x01(\x0c\x12\x0b\n\x03ovk\x18\x04 \x01(\x0c\x12\n\n\x02\x61k\x18\x05 \x01(\x0c\x12\n\n\x02nk\x18\x06 \x01(\x0c\x12\x0b\n\x03ivk\x18\x07 \x01(\x0c\x12\t\n\x01\x64\x18\x08 \x01(\x0c\x12\x0b\n\x03pkD\x18\t \x01(\x0c\x12\x17\n\x0fpayment_address\x18\n \x01(\t\"c\n\x0eNoteParameters\x12\n\n\x02\x61k\x18\x01 \x01(\x0c\x12\n\n\x02nk\x18\x02 \x01(\x0c\x12\x1c\n\x04note\x18\x03 \x01(\x0b\x32\x0e.protocol.Note\x12\x0c\n\x04txid\x18\x04 \x01(\x0c\x12\r\n\x05index\x18\x05 \x01(\x05\".\n\x0bSpendResult\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"I\n\x13TransactionInfoList\x12\x32\n\x0ftransactionInfo\x18\x01 \x03(\x0b\x32\x19.protocol.TransactionInfo\"f\n\x0eSpendNoteTRC20\x12\x1c\n\x04note\x18\x01 \x01(\x0b\x32\x0e.protocol.Note\x12\r\n\x05\x61lpha\x18\x02 \x01(\x0c\x12\x0c\n\x04root\x18\x03 \x01(\x0c\x12\x0c\n\x04path\x18\x04 \x01(\x0c\x12\x0b\n\x03pos\x18\x05 \x01(\x03\"\x9d\x02\n\x1ePrivateShieldedTRC20Parameters\x12\x0b\n\x03\x61sk\x18\x01 \x01(\x0c\x12\x0b\n\x03nsk\x18\x02 \x01(\x0c\x12\x0b\n\x03ovk\x18\x03 \x01(\x0c\x12\x13\n\x0b\x66rom_amount\x18\x04 \x01(\t\x12\x31\n\x0fshielded_spends\x18\x05 \x03(\x0b\x32\x18.protocol.SpendNoteTRC20\x12\x30\n\x11shielded_receives\x18\x06 \x03(\x0b\x32\x15.protocol.ReceiveNote\x12\x1e\n\x16transparent_to_address\x18\x07 \x01(\x0c\x12\x11\n\tto_amount\x18\x08 \x01(\t\x12\'\n\x1fshielded_TRC20_contract_address\x18\t \x01(\x0c\"\xa6\x02\n(PrivateShieldedTRC20ParametersWithoutAsk\x12\n\n\x02\x61k\x18\x01 \x01(\x0c\x12\x0b\n\x03nsk\x18\x02 \x01(\x0c\x12\x0b\n\x03ovk\x18\x03 \x01(\x0c\x12\x13\n\x0b\x66rom_amount\x18\x04 \x01(\t\x12\x31\n\x0fshielded_spends\x18\x05 \x03(\x0b\x32\x18.protocol.SpendNoteTRC20\x12\x30\n\x11shielded_receives\x18\x06 \x03(\x0b\x32\x15.protocol.ReceiveNote\x12\x1e\n\x16transparent_to_address\x18\x07 \x01(\x0c\x12\x11\n\tto_amount\x18\x08 \x01(\t\x12\'\n\x1fshielded_TRC20_contract_address\x18\t \x01(\x0c\"\xf4\x01\n\x17ShieldedTRC20Parameters\x12\x35\n\x11spend_description\x18\x01 \x03(\x0b\x32\x1a.protocol.SpendDescription\x12\x39\n\x13receive_description\x18\x02 \x03(\x0b\x32\x1c.protocol.ReceiveDescription\x12\x19\n\x11\x62inding_signature\x18\x03 \x01(\x0c\x12\x14\n\x0cmessage_hash\x18\x04 \x01(\x0c\x12\x1e\n\x16trigger_contract_input\x18\x05 \x01(\t\x12\x16\n\x0eparameter_type\x18\x06 \x01(\t\"\xad\x01\n\x19IvkDecryptTRC20Parameters\x12\x19\n\x11start_block_index\x18\x01 \x01(\x03\x12\x17\n\x0f\x65nd_block_index\x18\x02 \x01(\x03\x12\'\n\x1fshielded_TRC20_contract_address\x18\x03 \x01(\x0c\x12\x0b\n\x03ivk\x18\x04 \x01(\x0c\x12\n\n\x02\x61k\x18\x05 \x01(\x0c\x12\n\n\x02nk\x18\x06 \x01(\x0c\x12\x0e\n\x06\x65vents\x18\x07 \x03(\t\"\x95\x01\n\x19OvkDecryptTRC20Parameters\x12\x19\n\x11start_block_index\x18\x01 \x01(\x03\x12\x17\n\x0f\x65nd_block_index\x18\x02 \x01(\x03\x12\x0b\n\x03ovk\x18\x03 \x01(\x0c\x12\'\n\x1fshielded_TRC20_contract_address\x18\x04 \x01(\x0c\x12\x0e\n\x06\x65vents\x18\x05 \x03(\t\"\xe5\x01\n\x11\x44\x65\x63ryptNotesTRC20\x12\x33\n\x07noteTxs\x18\x01 \x03(\x0b\x32\".protocol.DecryptNotesTRC20.NoteTx\x1a\x9a\x01\n\x06NoteTx\x12\x1c\n\x04note\x18\x01 \x01(\x0b\x32\x0e.protocol.Note\x12\x10\n\x08position\x18\x02 \x01(\x03\x12\x10\n\x08is_spent\x18\x03 \x01(\x08\x12\x0c\n\x04txid\x18\x04 \x01(\x0c\x12\r\n\x05index\x18\x05 \x01(\x05\x12\x11\n\tto_amount\x18\x06 \x01(\t\x12\x1e\n\x16transparent_to_address\x18\x07 \x01(\x0c\"\x84\x01\n\x11NfTRC20Parameters\x12\x1c\n\x04note\x18\x01 \x01(\x0b\x32\x0e.protocol.Note\x12\n\n\x02\x61k\x18\x02 \x01(\x0c\x12\n\n\x02nk\x18\x03 \x01(\x0c\x12\x10\n\x08position\x18\x04 \x01(\x03\x12\'\n\x1fshielded_TRC20_contract_address\x18\x05 \x01(\x0c\"#\n\x0fNullifierResult\x12\x10\n\x08is_spent\x18\x01 \x01(\x08\"\xd9\x01\n&ShieldedTRC20TriggerContractParameters\x12\x44\n\x19shielded_TRC20_Parameters\x18\x01 \x01(\x0b\x32!.protocol.ShieldedTRC20Parameters\x12\x39\n\x19spend_authority_signature\x18\x02 \x03(\x0b\x32\x16.protocol.BytesMessage\x12\x0e\n\x06\x61mount\x18\x03 \x01(\t\x12\x1e\n\x16transparent_to_address\x18\x04 \x01(\x0c\x32\xa6t\n\x06Wallet\x12g\n\nGetAccount\x12\x11.protocol.Account\x1a\x11.protocol.Account\"3\x82\xd3\xe4\x93\x02-\"\x12/wallet/getaccount:\x01*Z\x14\x12\x12/wallet/getaccount\x12s\n\x0eGetAccountById\x12\x11.protocol.Account\x1a\x11.protocol.Account\";\x82\xd3\xe4\x93\x02\x35\"\x16/wallet/getaccountbyid:\x01*Z\x18\x12\x16/wallet/getaccountbyid\x12\x99\x01\n\x11GetAccountBalance\x12\x1f.protocol.AccountBalanceRequest\x1a .protocol.AccountBalanceResponse\"A\x82\xd3\xe4\x93\x02;\"\x19/wallet/getaccountbalance:\x01*Z\x1b\x12\x19/wallet/getaccountbalance\x12\xa9\x01\n\x14GetBlockBalanceTrace\x12+.protocol.BlockBalanceTrace.BlockIdentifier\x1a\x1b.protocol.BlockBalanceTrace\"G\x82\xd3\xe4\x93\x02\x41\"\x1c/wallet/getblockbalancetrace:\x01*Z\x1e\x12\x1c/wallet/getblockbalancetrace\x12\x89\x01\n\x11\x43reateTransaction\x12\x1a.protocol.TransferContract\x1a\x15.protocol.Transaction\"A\x82\xd3\xe4\x93\x02;\"\x19/wallet/createtransaction:\x01*Z\x1b\x12\x19/wallet/createtransaction\x12R\n\x12\x43reateTransaction2\x12\x1a.protocol.TransferContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12\x88\x01\n\x14\x42roadcastTransaction\x12\x15.protocol.Transaction\x1a\x10.protocol.Return\"G\x82\xd3\xe4\x93\x02\x41\"\x1c/wallet/broadcasttransaction:\x01*Z\x1e\x12\x1c/wallet/broadcasttransaction\x12\x82\x01\n\rUpdateAccount\x12\x1f.protocol.AccountUpdateContract\x1a\x15.protocol.Transaction\"9\x82\xd3\xe4\x93\x02\x33\"\x15/wallet/updateaccount:\x01*Z\x17\x12\x15/wallet/updateaccount\x12~\n\x0cSetAccountId\x12\x1e.protocol.SetAccountIdContract\x1a\x15.protocol.Transaction\"7\x82\xd3\xe4\x93\x02\x31\"\x14/wallet/setaccountid:\x01*Z\x16\x12\x14/wallet/setaccountid\x12S\n\x0eUpdateAccount2\x12\x1f.protocol.AccountUpdateContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12\x8f\x01\n\x12VoteWitnessAccount\x12\x1d.protocol.VoteWitnessContract\x1a\x15.protocol.Transaction\"C\x82\xd3\xe4\x93\x02=\"\x1a/wallet/votewitnessaccount:\x01*Z\x1c\x12\x1a/wallet/votewitnessaccount\x12R\n\rUpdateSetting\x12\x1f.protocol.UpdateSettingContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12Z\n\x11UpdateEnergyLimit\x12#.protocol.UpdateEnergyLimitContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12V\n\x13VoteWitnessAccount2\x12\x1d.protocol.VoteWitnessContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12\x88\x01\n\x10\x43reateAssetIssue\x12\x1c.protocol.AssetIssueContract\x1a\x15.protocol.Transaction\"?\x82\xd3\xe4\x93\x02\x39\"\x18/wallet/createassetissue:\x01*Z\x1a\x12\x18/wallet/createassetissue\x12S\n\x11\x43reateAssetIssue2\x12\x1c.protocol.AssetIssueContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12\x82\x01\n\rUpdateWitness\x12\x1f.protocol.WitnessUpdateContract\x1a\x15.protocol.Transaction\"9\x82\xd3\xe4\x93\x02\x33\"\x15/wallet/updatewitness:\x01*Z\x17\x12\x15/wallet/updatewitness\x12S\n\x0eUpdateWitness2\x12\x1f.protocol.WitnessUpdateContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12\x82\x01\n\rCreateAccount\x12\x1f.protocol.AccountCreateContract\x1a\x15.protocol.Transaction\"9\x82\xd3\xe4\x93\x02\x33\"\x15/wallet/createaccount:\x01*Z\x17\x12\x15/wallet/createaccount\x12S\n\x0e\x43reateAccount2\x12\x1f.protocol.AccountCreateContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12\x82\x01\n\rCreateWitness\x12\x1f.protocol.WitnessCreateContract\x1a\x15.protocol.Transaction\"9\x82\xd3\xe4\x93\x02\x33\"\x15/wallet/createwitness:\x01*Z\x17\x12\x15/wallet/createwitness\x12S\n\x0e\x43reateWitness2\x12\x1f.protocol.WitnessCreateContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12\x82\x01\n\rTransferAsset\x12\x1f.protocol.TransferAssetContract\x1a\x15.protocol.Transaction\"9\x82\xd3\xe4\x93\x02\x33\"\x15/wallet/transferasset:\x01*Z\x17\x12\x15/wallet/transferasset\x12S\n\x0eTransferAsset2\x12\x1f.protocol.TransferAssetContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12\xa2\x01\n\x15ParticipateAssetIssue\x12\'.protocol.ParticipateAssetIssueContract\x1a\x15.protocol.Transaction\"I\x82\xd3\xe4\x93\x02\x43\"\x1d/wallet/participateassetissue:\x01*Z\x1f\x12\x1d/wallet/participateassetissue\x12\x63\n\x16ParticipateAssetIssue2\x12\'.protocol.ParticipateAssetIssueContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12\x82\x01\n\rFreezeBalance\x12\x1f.protocol.FreezeBalanceContract\x1a\x15.protocol.Transaction\"9\x82\xd3\xe4\x93\x02\x33\"\x15/wallet/freezebalance:\x01*Z\x17\x12\x15/wallet/freezebalance\x12S\n\x0e\x46reezeBalance2\x12\x1f.protocol.FreezeBalanceContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12V\n\x0f\x46reezeBalanceV2\x12!.protocol.FreezeBalanceV2Contract\x1a\x1e.protocol.TransactionExtention\"\x00\x12\x8a\x01\n\x0fUnfreezeBalance\x12!.protocol.UnfreezeBalanceContract\x1a\x15.protocol.Transaction\"=\x82\xd3\xe4\x93\x02\x37\"\x17/wallet/unfreezebalance:\x01*Z\x19\x12\x17/wallet/unfreezebalance\x12W\n\x10UnfreezeBalance2\x12!.protocol.UnfreezeBalanceContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12Z\n\x11UnfreezeBalanceV2\x12#.protocol.UnfreezeBalanceV2Contract\x1a\x1e.protocol.TransactionExtention\"\x00\x12\x82\x01\n\rUnfreezeAsset\x12\x1f.protocol.UnfreezeAssetContract\x1a\x15.protocol.Transaction\"9\x82\xd3\xe4\x93\x02\x33\"\x15/wallet/unfreezeasset:\x01*Z\x17\x12\x15/wallet/unfreezeasset\x12S\n\x0eUnfreezeAsset2\x12\x1f.protocol.UnfreezeAssetContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12\x8a\x01\n\x0fWithdrawBalance\x12!.protocol.WithdrawBalanceContract\x1a\x15.protocol.Transaction\"=\x82\xd3\xe4\x93\x02\x37\"\x17/wallet/withdrawbalance:\x01*Z\x19\x12\x17/wallet/withdrawbalance\x12W\n\x10WithdrawBalance2\x12!.protocol.WithdrawBalanceContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12\x64\n\x16WithdrawExpireUnfreeze\x12(.protocol.WithdrawExpireUnfreezeContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12X\n\x10\x44\x65legateResource\x12\".protocol.DelegateResourceContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12\\\n\x12UnDelegateResource\x12$.protocol.UnDelegateResourceContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12^\n\x13\x43\x61ncelAllUnfreezeV2\x12%.protocol.CancelAllUnfreezeV2Contract\x1a\x1e.protocol.TransactionExtention\"\x00\x12z\n\x0bUpdateAsset\x12\x1d.protocol.UpdateAssetContract\x1a\x15.protocol.Transaction\"5\x82\xd3\xe4\x93\x02/\"\x13/wallet/updateasset:\x01*Z\x15\x12\x13/wallet/updateasset\x12O\n\x0cUpdateAsset2\x12\x1d.protocol.UpdateAssetContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12T\n\x0eProposalCreate\x12 .protocol.ProposalCreateContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12V\n\x0fProposalApprove\x12!.protocol.ProposalApproveContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12T\n\x0eProposalDelete\x12 .protocol.ProposalDeleteContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12L\n\nBuyStorage\x12\x1c.protocol.BuyStorageContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12V\n\x0f\x42uyStorageBytes\x12!.protocol.BuyStorageBytesContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12N\n\x0bSellStorage\x12\x1d.protocol.SellStorageContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12T\n\x0e\x45xchangeCreate\x12 .protocol.ExchangeCreateContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12T\n\x0e\x45xchangeInject\x12 .protocol.ExchangeInjectContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12X\n\x10\x45xchangeWithdraw\x12\".protocol.ExchangeWithdrawContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12^\n\x13\x45xchangeTransaction\x12%.protocol.ExchangeTransactionContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12V\n\x0fMarketSellAsset\x12!.protocol.MarketSellAssetContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12Z\n\x11MarketCancelOrder\x12#.protocol.MarketCancelOrderContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12\x45\n\x12GetMarketOrderById\x12\x16.protocol.BytesMessage\x1a\x15.protocol.MarketOrder\"\x00\x12N\n\x17GetMarketOrderByAccount\x12\x16.protocol.BytesMessage\x1a\x19.protocol.MarketOrderList\"\x00\x12N\n\x14GetMarketPriceByPair\x12\x19.protocol.MarketOrderPair\x1a\x19.protocol.MarketPriceList\"\x00\x12R\n\x18GetMarketOrderListByPair\x12\x19.protocol.MarketOrderPair\x1a\x19.protocol.MarketOrderList\"\x00\x12L\n\x11GetMarketPairList\x12\x16.protocol.EmptyMessage\x1a\x1d.protocol.MarketOrderPairList\"\x00\x12j\n\tListNodes\x12\x16.protocol.EmptyMessage\x1a\x12.protocol.NodeList\"1\x82\xd3\xe4\x93\x02+\"\x11/wallet/listnodes:\x01*Z\x13\x12\x11/wallet/listnodes\x12\x92\x01\n\x16GetAssetIssueByAccount\x12\x11.protocol.Account\x1a\x18.protocol.AssetIssueList\"K\x82\xd3\xe4\x93\x02\x45\"\x1e/wallet/getassetissuebyaccount:\x01*Z \x12\x1e/wallet/getassetissuebyaccount\x12z\n\rGetAccountNet\x12\x11.protocol.Account\x1a\x1b.protocol.AccountNetMessage\"9\x82\xd3\xe4\x93\x02\x33\"\x15/wallet/getaccountnet:\x01*Z\x17\x12\x15/wallet/getaccountnet\x12K\n\x12GetAccountResource\x12\x11.protocol.Account\x1a .protocol.AccountResourceMessage\"\x00\x12\x92\x01\n\x13GetAssetIssueByName\x12\x16.protocol.BytesMessage\x1a\x1c.protocol.AssetIssueContract\"E\x82\xd3\xe4\x93\x02?\"\x1b/wallet/getassetissuebyname:\x01*Z\x1d\x12\x1b/wallet/getassetissuebyname\x12M\n\x17GetAssetIssueListByName\x12\x16.protocol.BytesMessage\x1a\x18.protocol.AssetIssueList\"\x00\x12K\n\x11GetAssetIssueById\x12\x16.protocol.BytesMessage\x1a\x1c.protocol.AssetIssueContract\"\x00\x12m\n\x0bGetNowBlock\x12\x16.protocol.EmptyMessage\x1a\x0f.protocol.Block\"5\x82\xd3\xe4\x93\x02/\"\x13/wallet/getnowblock:\x01*Z\x15\x12\x13/wallet/getnowblock\x12\x42\n\x0cGetNowBlock2\x12\x16.protocol.EmptyMessage\x1a\x18.protocol.BlockExtention\"\x00\x12t\n\rGetBlockByNum\x12\x17.protocol.NumberMessage\x1a\x0f.protocol.Block\"9\x82\xd3\xe4\x93\x02\x33\"\x15/wallet/getblockbynum:\x01*Z\x17\x12\x15/wallet/getblockbynum\x12\x45\n\x0eGetBlockByNum2\x12\x17.protocol.NumberMessage\x1a\x18.protocol.BlockExtention\"\x00\x12S\n\x1dGetTransactionCountByBlockNum\x12\x17.protocol.NumberMessage\x1a\x17.protocol.NumberMessage\"\x00\x12p\n\x0cGetBlockById\x12\x16.protocol.BytesMessage\x1a\x0f.protocol.Block\"7\x82\xd3\xe4\x93\x02\x31\"\x14/wallet/getblockbyid:\x01*Z\x16\x12\x14/wallet/getblockbyid\x12\x87\x01\n\x13GetBlockByLimitNext\x12\x14.protocol.BlockLimit\x1a\x13.protocol.BlockList\"E\x82\xd3\xe4\x93\x02?\"\x1b/wallet/getblockbylimitnext:\x01*Z\x1d\x12\x1b/wallet/getblockbylimitnext\x12L\n\x14GetBlockByLimitNext2\x12\x14.protocol.BlockLimit\x1a\x1c.protocol.BlockListExtention\"\x00\x12\x8a\x01\n\x13GetBlockByLatestNum\x12\x17.protocol.NumberMessage\x1a\x13.protocol.BlockList\"E\x82\xd3\xe4\x93\x02?\"\x1b/wallet/getblockbylatestnum:\x01*Z\x1d\x12\x1b/wallet/getblockbylatestnum\x12O\n\x14GetBlockByLatestNum2\x12\x17.protocol.NumberMessage\x1a\x1c.protocol.BlockListExtention\"\x00\x12\x88\x01\n\x12GetTransactionById\x12\x16.protocol.BytesMessage\x1a\x15.protocol.Transaction\"C\x82\xd3\xe4\x93\x02=\"\x1a/wallet/gettransactionbyid:\x01*Z\x1c\x12\x1a/wallet/gettransactionbyid\x12Q\n\x0e\x44\x65ployContract\x12\x1d.protocol.CreateSmartContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12@\n\x0bGetContract\x12\x16.protocol.BytesMessage\x1a\x17.protocol.SmartContract\"\x00\x12O\n\x0fGetContractInfo\x12\x16.protocol.BytesMessage\x1a\".protocol.SmartContractDataWrapper\"\x00\x12S\n\x0fTriggerContract\x12\x1e.protocol.TriggerSmartContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12[\n\x17TriggerConstantContract\x12\x1e.protocol.TriggerSmartContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12S\n\x0e\x45stimateEnergy\x12\x1e.protocol.TriggerSmartContract\x1a\x1f.protocol.EstimateEnergyMessage\"\x00\x12P\n\x10\x43learContractABI\x12\x1a.protocol.ClearABIContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12y\n\rListWitnesses\x12\x16.protocol.EmptyMessage\x1a\x15.protocol.WitnessList\"9\x82\xd3\xe4\x93\x02\x33\"\x15/wallet/listwitnesses:\x01*Z\x17\x12\x15/wallet/listwitnesses\x12]\n\x14GetDelegatedResource\x12\".protocol.DelegatedResourceMessage\x1a\x1f.protocol.DelegatedResourceList\"\x00\x12_\n\x16GetDelegatedResourceV2\x12\".protocol.DelegatedResourceMessage\x1a\x1f.protocol.DelegatedResourceList\"\x00\x12\x65\n GetDelegatedResourceAccountIndex\x12\x16.protocol.BytesMessage\x1a\'.protocol.DelegatedResourceAccountIndex\"\x00\x12g\n\"GetDelegatedResourceAccountIndexV2\x12\x16.protocol.BytesMessage\x1a\'.protocol.DelegatedResourceAccountIndex\"\x00\x12u\n\x16GetCanDelegatedMaxSize\x12+.protocol.CanDelegatedMaxSizeRequestMessage\x1a,.protocol.CanDelegatedMaxSizeResponseMessage\"\x00\x12\x84\x01\n\x19GetAvailableUnfreezeCount\x12\x31.protocol.GetAvailableUnfreezeCountRequestMessage\x1a\x32.protocol.GetAvailableUnfreezeCountResponseMessage\"\x00\x12\x87\x01\n\x1cGetCanWithdrawUnfreezeAmount\x12\x31.protocol.CanWithdrawUnfreezeAmountRequestMessage\x1a\x32.protocol.CanWithdrawUnfreezeAmountResponseMessage\"\x00\x12z\n\rListProposals\x12\x16.protocol.EmptyMessage\x1a\x16.protocol.ProposalList\"9\x82\xd3\xe4\x93\x02\x33\"\x15/wallet/listproposals:\x01*Z\x17\x12\x15/wallet/listproposals\x12\x9f\x01\n\x18GetPaginatedProposalList\x12\x1a.protocol.PaginatedMessage\x1a\x16.protocol.ProposalList\"O\x82\xd3\xe4\x93\x02I\" /wallet/getpaginatedproposallist:\x01*Z\"\x12 /wallet/getpaginatedproposallist\x12|\n\x0fGetProposalById\x12\x16.protocol.BytesMessage\x1a\x12.protocol.Proposal\"=\x82\xd3\xe4\x93\x02\x37\"\x17/wallet/getproposalbyid:\x01*Z\x19\x12\x17/wallet/getproposalbyid\x12z\n\rListExchanges\x12\x16.protocol.EmptyMessage\x1a\x16.protocol.ExchangeList\"9\x82\xd3\xe4\x93\x02\x33\"\x15/wallet/listexchanges:\x01*Z\x17\x12\x15/wallet/listexchanges\x12\x9f\x01\n\x18GetPaginatedExchangeList\x12\x1a.protocol.PaginatedMessage\x1a\x16.protocol.ExchangeList\"O\x82\xd3\xe4\x93\x02I\" /wallet/getpaginatedexchangelist:\x01*Z\"\x12 /wallet/getpaginatedexchangelist\x12|\n\x0fGetExchangeById\x12\x16.protocol.BytesMessage\x1a\x12.protocol.Exchange\"=\x82\xd3\xe4\x93\x02\x37\"\x17/wallet/getexchangebyid:\x01*Z\x19\x12\x17/wallet/getexchangebyid\x12\x8c\x01\n\x12GetChainParameters\x12\x16.protocol.EmptyMessage\x1a\x19.protocol.ChainParameters\"C\x82\xd3\xe4\x93\x02=\"\x1a/wallet/getchainparameters:\x01*Z\x1c\x12\x1a/wallet/getchainparameters\x12\x88\x01\n\x11GetAssetIssueList\x12\x16.protocol.EmptyMessage\x1a\x18.protocol.AssetIssueList\"A\x82\xd3\xe4\x93\x02;\"\x19/wallet/getassetissuelist:\x01*Z\x1b\x12\x19/wallet/getassetissuelist\x12\xa7\x01\n\x1aGetPaginatedAssetIssueList\x12\x1a.protocol.PaginatedMessage\x1a\x18.protocol.AssetIssueList\"S\x82\xd3\xe4\x93\x02M\"\"/wallet/getpaginatedassetissuelist:\x01*Z$\x12\"/wallet/getpaginatedassetissuelist\x12\x84\x01\n\x10TotalTransaction\x12\x16.protocol.EmptyMessage\x1a\x17.protocol.NumberMessage\"?\x82\xd3\xe4\x93\x02\x39\"\x18/wallet/totaltransaction:\x01*Z\x1a\x12\x18/wallet/totaltransaction\x12\x96\x01\n\x16GetNextMaintenanceTime\x12\x16.protocol.EmptyMessage\x1a\x17.protocol.NumberMessage\"K\x82\xd3\xe4\x93\x02\x45\"\x1e/wallet/getnextmaintenancetime:\x01*Z \x12\x1e/wallet/getnextmaintenancetime\x12\x98\x01\n\x16GetTransactionInfoById\x12\x16.protocol.BytesMessage\x1a\x19.protocol.TransactionInfo\"K\x82\xd3\xe4\x93\x02\x45\"\x1e/wallet/gettransactioninfobyid:\x01*Z \x12\x1e/wallet/gettransactioninfobyid\x12\xb3\x01\n\x17\x41\x63\x63ountPermissionUpdate\x12).protocol.AccountPermissionUpdateContract\x1a\x1e.protocol.TransactionExtention\"M\x82\xd3\xe4\x93\x02G\"\x1f/wallet/accountpermissionupdate:\x01*Z!\x12\x1f/wallet/accountpermissionupdate\x12T\n\x18GetTransactionSignWeight\x12\x15.protocol.Transaction\x1a\x1f.protocol.TransactionSignWeight\"\x00\x12X\n\x1aGetTransactionApprovedList\x12\x15.protocol.Transaction\x1a!.protocol.TransactionApprovedList\"\x00\x12;\n\x0bGetNodeInfo\x12\x16.protocol.EmptyMessage\x1a\x12.protocol.NodeInfo\"\x00\x12\x42\n\rGetRewardInfo\x12\x16.protocol.BytesMessage\x1a\x17.protocol.NumberMessage\"\x00\x12\x45\n\x10GetBrokerageInfo\x12\x16.protocol.BytesMessage\x1a\x17.protocol.NumberMessage\"\x00\x12V\n\x0fUpdateBrokerage\x12!.protocol.UpdateBrokerageContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12Z\n\x19\x43reateShieldedTransaction\x12\x1b.protocol.PrivateParameters\x1a\x1e.protocol.TransactionExtention\"\x00\x12_\n\x18GetMerkleTreeVoucherInfo\x12\x19.protocol.OutputPointInfo\x1a&.protocol.IncrementalMerkleVoucherInfo\"\x00\x12I\n\rScanNoteByIvk\x12\x1e.protocol.IvkDecryptParameters\x1a\x16.protocol.DecryptNotes\"\x00\x12]\n\x14ScanAndMarkNoteByIvk\x12%.protocol.IvkDecryptAndMarkParameters\x1a\x1c.protocol.DecryptNotesMarked\"\x00\x12I\n\rScanNoteByOvk\x12\x1e.protocol.OvkDecryptParameters\x1a\x16.protocol.DecryptNotes\"\x00\x12\x42\n\x0eGetSpendingKey\x12\x16.protocol.EmptyMessage\x1a\x16.protocol.BytesMessage\"\x00\x12X\n\x16GetExpandedSpendingKey\x12\x16.protocol.BytesMessage\x1a$.protocol.ExpandedSpendingKeyMessage\"\x00\x12@\n\x0cGetAkFromAsk\x12\x16.protocol.BytesMessage\x1a\x16.protocol.BytesMessage\"\x00\x12@\n\x0cGetNkFromNsk\x12\x16.protocol.BytesMessage\x1a\x16.protocol.BytesMessage\"\x00\x12[\n\x15GetIncomingViewingKey\x12\x1b.protocol.ViewingKeyMessage\x1a#.protocol.IncomingViewingKeyMessage\"\x00\x12H\n\x0eGetDiversifier\x12\x16.protocol.EmptyMessage\x1a\x1c.protocol.DiversifierMessage\"\x00\x12P\n\x15GetNewShieldedAddress\x12\x16.protocol.EmptyMessage\x1a\x1d.protocol.ShieldedAddressInfo\"\x00\x12i\n\x14GetZenPaymentAddress\x12..protocol.IncomingViewingKeyDiversifierMessage\x1a\x1f.protocol.PaymentAddressMessage\"\x00\x12:\n\x06GetRcm\x12\x16.protocol.EmptyMessage\x1a\x16.protocol.BytesMessage\"\x00\x12<\n\x07IsSpend\x12\x18.protocol.NoteParameters\x1a\x15.protocol.SpendResult\"\x00\x12w\n,CreateShieldedTransactionWithoutSpendAuthSig\x12%.protocol.PrivateParametersWithoutAsk\x1a\x1e.protocol.TransactionExtention\"\x00\x12K\n\x18GetShieldTransactionHash\x12\x15.protocol.Transaction\x1a\x16.protocol.BytesMessage\"\x00\x12P\n\x12\x43reateSpendAuthSig\x12 .protocol.SpendAuthSigParameters\x1a\x16.protocol.BytesMessage\"\x00\x12I\n\x15\x43reateShieldNullifier\x12\x16.protocol.NfParameters\x1a\x16.protocol.BytesMessage\"\x00\x12q\n CreateShieldedContractParameters\x12(.protocol.PrivateShieldedTRC20Parameters\x1a!.protocol.ShieldedTRC20Parameters\"\x00\x12\x85\x01\n*CreateShieldedContractParametersWithoutAsk\x12\x32.protocol.PrivateShieldedTRC20ParametersWithoutAsk\x1a!.protocol.ShieldedTRC20Parameters\"\x00\x12\x61\n\x1bScanShieldedTRC20NotesByIvk\x12#.protocol.IvkDecryptTRC20Parameters\x1a\x1b.protocol.DecryptNotesTRC20\"\x00\x12\x61\n\x1bScanShieldedTRC20NotesByOvk\x12#.protocol.OvkDecryptTRC20Parameters\x1a\x1b.protocol.DecryptNotesTRC20\"\x00\x12\\\n IsShieldedTRC20ContractNoteSpent\x12\x1b.protocol.NfTRC20Parameters\x1a\x19.protocol.NullifierResult\"\x00\x12u\n\'GetTriggerInputForShieldedTRC20Contract\x12\x30.protocol.ShieldedTRC20TriggerContractParameters\x1a\x16.protocol.BytesMessage\"\x00\x12R\n\x17\x43reateCommonTransaction\x12\x15.protocol.Transaction\x1a\x1e.protocol.TransactionExtention\"\x00\x12X\n\x1cGetTransactionInfoByBlockNum\x12\x17.protocol.NumberMessage\x1a\x1d.protocol.TransactionInfoList\"\x00\x12?\n\nGetBurnTrx\x12\x16.protocol.EmptyMessage\x1a\x17.protocol.NumberMessage\"\x00\x12L\n\x19GetTransactionFromPending\x12\x16.protocol.BytesMessage\x1a\x15.protocol.Transaction\"\x00\x12V\n\x1dGetTransactionListFromPending\x12\x16.protocol.EmptyMessage\x1a\x1b.protocol.TransactionIdList\"\x00\x12\x43\n\x0eGetPendingSize\x12\x16.protocol.EmptyMessage\x1a\x17.protocol.NumberMessage\"\x00\x12:\n\x08GetBlock\x12\x12.protocol.BlockReq\x1a\x18.protocol.BlockExtention\"\x00\x12O\n\x12GetBandwidthPrices\x12\x16.protocol.EmptyMessage\x1a\x1f.protocol.PricesResponseMessage\"\x00\x12L\n\x0fGetEnergyPrices\x12\x16.protocol.EmptyMessage\x1a\x1f.protocol.PricesResponseMessage\"\x00\x12G\n\nGetMemoFee\x12\x16.protocol.EmptyMessage\x1a\x1f.protocol.PricesResponseMessage\"\x00\x32\x97#\n\x0eWalletSolidity\x12w\n\nGetAccount\x12\x11.protocol.Account\x1a\x11.protocol.Account\"C\x82\xd3\xe4\x93\x02=\"\x1a/walletsolidity/getaccount:\x01*Z\x1c\x12\x1a/walletsolidity/getaccount\x12\x83\x01\n\x0eGetAccountById\x12\x11.protocol.Account\x1a\x11.protocol.Account\"K\x82\xd3\xe4\x93\x02\x45\"\x1e/walletsolidity/getaccountbyid:\x01*Z \x12\x1e/walletsolidity/getaccountbyid\x12\x89\x01\n\rListWitnesses\x12\x16.protocol.EmptyMessage\x1a\x15.protocol.WitnessList\"I\x82\xd3\xe4\x93\x02\x43\"\x1d/walletsolidity/listwitnesses:\x01*Z\x1f\x12\x1d/walletsolidity/listwitnesses\x12\x98\x01\n\x11GetAssetIssueList\x12\x16.protocol.EmptyMessage\x1a\x18.protocol.AssetIssueList\"Q\x82\xd3\xe4\x93\x02K\"!/walletsolidity/getassetissuelist:\x01*Z#\x12!/walletsolidity/getassetissuelist\x12\xb7\x01\n\x1aGetPaginatedAssetIssueList\x12\x1a.protocol.PaginatedMessage\x1a\x18.protocol.AssetIssueList\"c\x82\xd3\xe4\x93\x02]\"*/walletsolidity/getpaginatedassetissuelist:\x01*Z,\x12*/walletsolidity/getpaginatedassetissuelist\x12M\n\x13GetAssetIssueByName\x12\x16.protocol.BytesMessage\x1a\x1c.protocol.AssetIssueContract\"\x00\x12M\n\x17GetAssetIssueListByName\x12\x16.protocol.BytesMessage\x1a\x18.protocol.AssetIssueList\"\x00\x12K\n\x11GetAssetIssueById\x12\x16.protocol.BytesMessage\x1a\x1c.protocol.AssetIssueContract\"\x00\x12}\n\x0bGetNowBlock\x12\x16.protocol.EmptyMessage\x1a\x0f.protocol.Block\"E\x82\xd3\xe4\x93\x02?\"\x1b/walletsolidity/getnowblock:\x01*Z\x1d\x12\x1b/walletsolidity/getnowblock\x12\x42\n\x0cGetNowBlock2\x12\x16.protocol.EmptyMessage\x1a\x18.protocol.BlockExtention\"\x00\x12\x84\x01\n\rGetBlockByNum\x12\x17.protocol.NumberMessage\x1a\x0f.protocol.Block\"I\x82\xd3\xe4\x93\x02\x43\"\x1d/walletsolidity/getblockbynum:\x01*Z\x1f\x12\x1d/walletsolidity/getblockbynum\x12\x45\n\x0eGetBlockByNum2\x12\x17.protocol.NumberMessage\x1a\x18.protocol.BlockExtention\"\x00\x12S\n\x1dGetTransactionCountByBlockNum\x12\x17.protocol.NumberMessage\x1a\x17.protocol.NumberMessage\"\x00\x12]\n\x14GetDelegatedResource\x12\".protocol.DelegatedResourceMessage\x1a\x1f.protocol.DelegatedResourceList\"\x00\x12_\n\x16GetDelegatedResourceV2\x12\".protocol.DelegatedResourceMessage\x1a\x1f.protocol.DelegatedResourceList\"\x00\x12\x65\n GetDelegatedResourceAccountIndex\x12\x16.protocol.BytesMessage\x1a\'.protocol.DelegatedResourceAccountIndex\"\x00\x12g\n\"GetDelegatedResourceAccountIndexV2\x12\x16.protocol.BytesMessage\x1a\'.protocol.DelegatedResourceAccountIndex\"\x00\x12u\n\x16GetCanDelegatedMaxSize\x12+.protocol.CanDelegatedMaxSizeRequestMessage\x1a,.protocol.CanDelegatedMaxSizeResponseMessage\"\x00\x12\x84\x01\n\x19GetAvailableUnfreezeCount\x12\x31.protocol.GetAvailableUnfreezeCountRequestMessage\x1a\x32.protocol.GetAvailableUnfreezeCountResponseMessage\"\x00\x12\x87\x01\n\x1cGetCanWithdrawUnfreezeAmount\x12\x31.protocol.CanWithdrawUnfreezeAmountRequestMessage\x1a\x32.protocol.CanWithdrawUnfreezeAmountResponseMessage\"\x00\x12?\n\x0fGetExchangeById\x12\x16.protocol.BytesMessage\x1a\x12.protocol.Exchange\"\x00\x12\x41\n\rListExchanges\x12\x16.protocol.EmptyMessage\x1a\x16.protocol.ExchangeList\"\x00\x12\x98\x01\n\x12GetTransactionById\x12\x16.protocol.BytesMessage\x1a\x15.protocol.Transaction\"S\x82\xd3\xe4\x93\x02M\"\"/walletsolidity/gettransactionbyid:\x01*Z$\x12\"/walletsolidity/gettransactionbyid\x12\xa8\x01\n\x16GetTransactionInfoById\x12\x16.protocol.BytesMessage\x1a\x19.protocol.TransactionInfo\"[\x82\xd3\xe4\x93\x02U\"&/walletsolidity/gettransactioninfobyid:\x01*Z(\x12&/walletsolidity/gettransactioninfobyid\x12_\n\x18GetMerkleTreeVoucherInfo\x12\x19.protocol.OutputPointInfo\x1a&.protocol.IncrementalMerkleVoucherInfo\"\x00\x12I\n\rScanNoteByIvk\x12\x1e.protocol.IvkDecryptParameters\x1a\x16.protocol.DecryptNotes\"\x00\x12]\n\x14ScanAndMarkNoteByIvk\x12%.protocol.IvkDecryptAndMarkParameters\x1a\x1c.protocol.DecryptNotesMarked\"\x00\x12I\n\rScanNoteByOvk\x12\x1e.protocol.OvkDecryptParameters\x1a\x16.protocol.DecryptNotes\"\x00\x12<\n\x07IsSpend\x12\x18.protocol.NoteParameters\x1a\x15.protocol.SpendResult\"\x00\x12\x61\n\x1bScanShieldedTRC20NotesByIvk\x12#.protocol.IvkDecryptTRC20Parameters\x1a\x1b.protocol.DecryptNotesTRC20\"\x00\x12\x61\n\x1bScanShieldedTRC20NotesByOvk\x12#.protocol.OvkDecryptTRC20Parameters\x1a\x1b.protocol.DecryptNotesTRC20\"\x00\x12\\\n IsShieldedTRC20ContractNoteSpent\x12\x1b.protocol.NfTRC20Parameters\x1a\x19.protocol.NullifierResult\"\x00\x12\x42\n\rGetRewardInfo\x12\x16.protocol.BytesMessage\x1a\x17.protocol.NumberMessage\"\x00\x12\x45\n\x10GetBrokerageInfo\x12\x16.protocol.BytesMessage\x1a\x17.protocol.NumberMessage\"\x00\x12[\n\x17TriggerConstantContract\x12\x1e.protocol.TriggerSmartContract\x1a\x1e.protocol.TransactionExtention\"\x00\x12S\n\x0e\x45stimateEnergy\x12\x1e.protocol.TriggerSmartContract\x1a\x1f.protocol.EstimateEnergyMessage\"\x00\x12X\n\x1cGetTransactionInfoByBlockNum\x12\x17.protocol.NumberMessage\x1a\x1d.protocol.TransactionInfoList\"\x00\x12\x45\n\x12GetMarketOrderById\x12\x16.protocol.BytesMessage\x1a\x15.protocol.MarketOrder\"\x00\x12N\n\x17GetMarketOrderByAccount\x12\x16.protocol.BytesMessage\x1a\x19.protocol.MarketOrderList\"\x00\x12N\n\x14GetMarketPriceByPair\x12\x19.protocol.MarketOrderPair\x1a\x19.protocol.MarketPriceList\"\x00\x12R\n\x18GetMarketOrderListByPair\x12\x19.protocol.MarketOrderPair\x1a\x19.protocol.MarketOrderList\"\x00\x12L\n\x11GetMarketPairList\x12\x16.protocol.EmptyMessage\x1a\x1d.protocol.MarketOrderPairList\"\x00\x12?\n\nGetBurnTrx\x12\x16.protocol.EmptyMessage\x1a\x17.protocol.NumberMessage\"\x00\x12:\n\x08GetBlock\x12\x12.protocol.BlockReq\x1a\x18.protocol.BlockExtention\"\x00\x12O\n\x12GetBandwidthPrices\x12\x16.protocol.EmptyMessage\x1a\x1f.protocol.PricesResponseMessage\"\x00\x12L\n\x0fGetEnergyPrices\x12\x16.protocol.EmptyMessage\x1a\x1f.protocol.PricesResponseMessage\"\x00\x32\xad\x04\n\x0fWalletExtension\x12\xb1\x01\n\x17GetTransactionsFromThis\x12\x1a.protocol.AccountPaginated\x1a\x19.protocol.TransactionList\"_\x82\xd3\xe4\x93\x02Y\"(/walletextension/gettransactionsfromthis:\x01*Z*\x12(/walletextension/gettransactionsfromthis\x12\\\n\x18GetTransactionsFromThis2\x12\x1a.protocol.AccountPaginated\x1a\".protocol.TransactionListExtention\"\x00\x12\xab\x01\n\x15GetTransactionsToThis\x12\x1a.protocol.AccountPaginated\x1a\x19.protocol.TransactionList\"[\x82\xd3\xe4\x93\x02U\"&/walletextension/gettransactionstothis:\x01*Z(\x12&/walletextension/gettransactionstothis\x12Z\n\x16GetTransactionsToThis2\x12\x1a.protocol.AccountPaginated\x1a\".protocol.TransactionListExtention\"\x00\x32\x99\x02\n\x08\x44\x61tabase\x12G\n\x11getBlockReference\x12\x16.protocol.EmptyMessage\x1a\x18.protocol.BlockReference\"\x00\x12M\n\x14GetDynamicProperties\x12\x16.protocol.EmptyMessage\x1a\x1b.protocol.DynamicProperties\"\x00\x12\x38\n\x0bGetNowBlock\x12\x16.protocol.EmptyMessage\x1a\x0f.protocol.Block\"\x00\x12;\n\rGetBlockByNum\x12\x17.protocol.NumberMessage\x1a\x0f.protocol.Block\"\x00\x32\x83\x01\n\x07Monitor\x12x\n\x0cGetStatsInfo\x12\x16.protocol.EmptyMessage\x1a\x15.protocol.MetricsInfo\"9\x82\xd3\xe4\x93\x02\x33\"\x15/monitor/getstatsinfo:\x01*Z\x17\x12\x15/monitor/getstatsinfo2\t\n\x07NetworkBA\n\x0corg.tron.apiB\x07GrpcAPIZ(github.com/tronprotocol/grpc-gateway/apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tron_sdk_py.proto.api.api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014org.tron.apiB\007GrpcAPIZ(github.com/tronprotocol/grpc-gateway/api'
  _globals['_ACCOUNTNETMESSAGE_ASSETNETUSEDENTRY']._loaded_options = None
  _globals['_ACCOUNTNETMESSAGE_ASSETNETUSEDENTRY']._serialized_options = b'8\001'
  _globals['_ACCOUNTNETMESSAGE_ASSETNETLIMITENTRY']._loaded_options = None
  _globals['_ACCOUNTNETMESSAGE_ASSETNETLIMITENTRY']._serialized_options = b'8\001'
  _globals['_ACCOUNTRESOURCEMESSAGE_ASSETNETUSEDENTRY']._loaded_options = None
  _globals['_ACCOUNTRESOURCEMESSAGE_ASSETNETUSEDENTRY']._serialized_options = b'8\001'
  _globals['_ACCOUNTRESOURCEMESSAGE_ASSETNETLIMITENTRY']._loaded_options = None
  _globals['_ACCOUNTRESOURCEMESSAGE_ASSETNETLIMITENTRY']._serialized_options = b'8\001'
  _globals['_WALLET'].methods_by_name['GetAccount']._loaded_options = None
  _globals['_WALLET'].methods_by_name['GetAccount']._serialized_options = b'\202\323\344\223\002-\"\022/wallet/getaccount:\001*Z\024\022\022/wallet/getaccount'
  _globals['_WALLET'].methods_by_name['GetAccountById']._loaded_options = None
  _globals['_WALLET'].methods_by_name['GetAccountById']._serialized_options = b'\202\323\344\223\0025\"\026/wallet/getaccountbyid:\001*Z\030\022\026/wallet/getaccountbyid'
  _globals['_WALLET'].methods_by_name['GetAccountBalance']._loaded_options = None
  _globals['_WALLET'].methods_by_name['GetAccountBalance']._serialized_options = b'\202\323\344\223\002;\"\031/wallet/getaccountbalance:\001*Z\033\022\031/wallet/getaccountbalance'
  _globals['_WALLET'].methods_by_name['GetBlockBalanceTrace']._loaded_options = None
  _globals['_WALLET'].methods_by_name['GetBlockBalanceTrace']._serialized_options = b'\202\323\344\223\002A\"\034/wallet/getblockbalancetrace:\001*Z\036\022\034/wallet/getblockbalancetrace'
  _globals['_WALLET'].methods_by_name['CreateTransaction']._loaded_options = None
  _globals['_WALLET'].methods_by_name['CreateTransaction']._serialized_options = b'\202\323\344\223\002;\"\031/wallet/createtransaction:\001*Z\033\022\031/wallet/createtransaction'
  _globals['_WALLET'].methods_by_name['BroadcastTransaction']._loaded_options = None
  _globals['_WALLET'].methods_by_name['BroadcastTransaction']._serialized_options = b'\202\323\344\223\002A\"\034/wallet/broadcasttransaction:\001*Z\036\022\034/wallet/broadcasttransaction'
  _globals['_WALLET'].methods_by_name['UpdateAccount']._loaded_options = None
  _globals['_WALLET'].methods_by_name['UpdateAccount']._serialized_options = b'\202\323\344\223\0023\"\025/wallet/updateaccount:\001*Z\027\022\025/wallet/updateaccount'
  _globals['_WALLET'].methods_by_name['SetAccountId']._loaded_options = None
  _globals['_WALLET'].methods_by_name['SetAccountId']._serialized_options = b'\202\323\344\223\0021\"\024/wallet/setaccountid:\001*Z\026\022\024/wallet/setaccountid'
  _globals['_WALLET'].methods_by_name['VoteWitnessAccount']._loaded_options = None
  _globals['_WALLET'].methods_by_name['VoteWitnessAccount']._serialized_options = b'\202\323\344\223\002=\"\032/wallet/votewitnessaccount:\001*Z\034\022\032/wallet/votewitnessaccount'
  _globals['_WALLET'].methods_by_name['CreateAssetIssue']._loaded_options = None
  _globals['_WALLET'].methods_by_name['CreateAssetIssue']._serialized_options = b'\202\323\344\223\0029\"\030/wallet/createassetissue:\001*Z\032\022\030/wallet/createassetissue'
  _globals['_WALLET'].methods_by_name['UpdateWitness']._loaded_options = None
  _globals['_WALLET'].methods_by_name['UpdateWitness']._serialized_options = b'\202\323\344\223\0023\"\025/wallet/updatewitness:\001*Z\027\022\025/wallet/updatewitness'
  _globals['_WALLET'].methods_by_name['CreateAccount']._loaded_options = None
  _globals['_WALLET'].methods_by_name['CreateAccount']._serialized_options = b'\202\323\344\223\0023\"\025/wallet/createaccount:\001*Z\027\022\025/wallet/createaccount'
  _globals['_WALLET'].methods_by_name['CreateWitness']._loaded_options = None
  _globals['_WALLET'].methods_by_name['CreateWitness']._serialized_options = b'\202\323\344\223\0023\"\025/wallet/createwitness:\001*Z\027\022\025/wallet/createwitness'
  _globals['_WALLET'].methods_by_name['TransferAsset']._loaded_options = None
  _globals['_WALLET'].methods_by_name['TransferAsset']._serialized_options = b'\202\323\344\223\0023\"\025/wallet/transferasset:\001*Z\027\022\025/wallet/transferasset'
  _globals['_WALLET'].methods_by_name['ParticipateAssetIssue']._loaded_options = None
  _globals['_WALLET'].methods_by_name['ParticipateAssetIssue']._serialized_options = b'\202\323\344\223\002C\"\035/wallet/participateassetissue:\001*Z\037\022\035/wallet/participateassetissue'
  _globals['_WALLET'].methods_by_name['FreezeBalance']._loaded_options = None
  _globals['_WALLET'].methods_by_name['FreezeBalance']._serialized_options = b'\202\323\344\223\0023\"\025/wallet/freezebalance:\001*Z\027\022\025/wallet/freezebalance'
  _globals['_WALLET'].methods_by_name['UnfreezeBalance']._loaded_options = None
  _globals['_WALLET'].methods_by_name['UnfreezeBalance']._serialized_options = b'\202\323\344\223\0027\"\027/wallet/unfreezebalance:\001*Z\031\022\027/wallet/unfreezebalance'
  _globals['_WALLET'].methods_by_name['UnfreezeAsset']._loaded_options = None
  _globals['_WALLET'].methods_by_name['UnfreezeAsset']._serialized_options = b'\202\323\344\223\0023\"\025/wallet/unfreezeasset:\001*Z\027\022\025/wallet/unfreezeasset'
  _globals['_WALLET'].methods_by_name['WithdrawBalance']._loaded_options = None
  _globals['_WALLET'].methods_by_name['WithdrawBalance']._serialized_options = b'\202\323\344\223\0027\"\027/wallet/withdrawbalance:\001*Z\031\022\027/wallet/withdrawbalance'
  _globals['_WALLET'].methods_by_name['UpdateAsset']._loaded_options = None
  _globals['_WALLET'].methods_by_name['UpdateAsset']._serialized_options = b'\202\323\344\223\002/\"\023/wallet/updateasset:\001*Z\025\022\023/wallet/updateasset'
  _globals['_WALLET'].methods_by_name['ListNodes']._loaded_options = None
  _globals['_WALLET'].methods_by_name['ListNodes']._serialized_options = b'\202\323\344\223\002+\"\021/wallet/listnodes:\001*Z\023\022\021/wallet/listnodes'
  _globals['_WALLET'].methods_by_name['GetAssetIssueByAccount']._loaded_options = None
  _globals['_WALLET'].methods_by_name['GetAssetIssueByAccount']._serialized_options = b'\202\323\344\223\002E\"\036/wallet/getassetissuebyaccount:\001*Z \022\036/wallet/getassetissuebyaccount'
  _globals['_WALLET'].methods_by_name['GetAccountNet']._loaded_options = None
  _globals['_WALLET'].methods_by_name['GetAccountNet']._serialized_options = b'\202\323\344\223\0023\"\025/wallet/getaccountnet:\001*Z\027\022\025/wallet/getaccountnet'
  _globals['_WALLET'].methods_by_name['GetAssetIssueByName']._loaded_options = None
  _globals['_WALLET'].methods_by_name['GetAssetIssueByName']._serialized_options = b'\202\323\344\223\002?\"\033/wallet/getassetissuebyname:\001*Z\035\022\033/wallet/getassetissuebyname'
  _globals['_WALLET'].methods_by_name['GetNowBlock']._loaded_options = None
  _globals['_WALLET'].methods_by_name['GetNowBlock']._serialized_options = b'\202\323\344\223\002/\"\023/wallet/getnowblock:\001*Z\025\022\023/wallet/getnowblock'
  _globals['_WALLET'].methods_by_name['GetBlockByNum']._loaded_options = None
  _globals['_WALLET'].methods_by_name['GetBlockByNum']._serialized_options = b'\202\323\344\223\0023\"\025/wallet/getblockbynum:\001*Z\027\022\025/wallet/getblockbynum'
  _globals['_WALLET'].methods_by_name['GetBlockById']._loaded_options = None
  _globals['_WALLET'].methods_by_name['GetBlockById']._serialized_options = b'\202\323\344\223\0021\"\024/wallet/getblockbyid:\001*Z\026\022\024/wallet/getblockbyid'
  _globals['_WALLET'].methods_by_name['GetBlockByLimitNext']._loaded_options = None
  _globals['_WALLET'].methods_by_name['GetBlockByLimitNext']._serialized_options = b'\202\323\344\223\002?\"\033/wallet/getblockbylimitnext:\001*Z\035\022\033/wallet/getblockbylimitnext'
  _globals['_WALLET'].methods_by_name['GetBlockByLatestNum']._loaded_options = None
  _globals['_WALLET'].methods_by_name['GetBlockByLatestNum']._serialized_options = b'\202\323\344\223\002?\"\033/wallet/getblockbylatestnum:\001*Z\035\022\033/wallet/getblockbylatestnum'
  _globals['_WALLET'].methods_by_name['GetTransactionById']._loaded_options = None
  _globals['_WALLET'].methods_by_name['GetTransactionById']._serialized_options = b'\202\323\344\223\002=\"\032/wallet/gettransactionbyid:\001*Z\034\022\032/wallet/gettransactionbyid'
  _globals['_WALLET'].methods_by_name['ListWitnesses']._loaded_options = None
  _globals['_WALLET'].methods_by_name['ListWitnesses']._serialized_options = b'\202\323\344\223\0023\"\025/wallet/listwitnesses:\001*Z\027\022\025/wallet/listwitnesses'
  _globals['_WALLET'].methods_by_name['ListProposals']._loaded_options = None
  _globals['_WALLET'].methods_by_name['ListProposals']._serialized_options = b'\202\323\344\223\0023\"\025/wallet/listproposals:\001*Z\027\022\025/wallet/listproposals'
  _globals['_WALLET'].methods_by_name['GetPaginatedProposalList']._loaded_options = None
  _globals['_WALLET'].methods_by_name['GetPaginatedProposalList']._serialized_options = b'\202\323\344\223\002I\" /wallet/getpaginatedproposallist:\001*Z\"\022 /wallet/getpaginatedproposallist'
  _globals['_WALLET'].methods_by_name['GetProposalById']._loaded_options = None
  _globals['_WALLET'].methods_by_name['GetProposalById']._serialized_options = b'\202\323\344\223\0027\"\027/wallet/getproposalbyid:\001*Z\031\022\027/wallet/getproposalbyid'
  _globals['_WALLET'].methods_by_name['ListExchanges']._loaded_options = None
  _globals['_WALLET'].methods_by_name['ListExchanges']._serialized_options = b'\202\323\344\223\0023\"\025/wallet/listexchanges:\001*Z\027\022\025/wallet/listexchanges'
  _globals['_WALLET'].methods_by_name['GetPaginatedExchangeList']._loaded_options = None
  _globals['_WALLET'].methods_by_name['GetPaginatedExchangeList']._serialized_options = b'\202\323\344\223\002I\" /wallet/getpaginatedexchangelist:\001*Z\"\022 /wallet/getpaginatedexchangelist'
  _globals['_WALLET'].methods_by_name['GetExchangeById']._loaded_options = None
  _globals['_WALLET'].methods_by_name['GetExchangeById']._serialized_options = b'\202\323\344\223\0027\"\027/wallet/getexchangebyid:\001*Z\031\022\027/wallet/getexchangebyid'
  _globals['_WALLET'].methods_by_name['GetChainParameters']._loaded_options = None
  _globals['_WALLET'].methods_by_name['GetChainParameters']._serialized_options = b'\202\323\344\223\002=\"\032/wallet/getchainparameters:\001*Z\034\022\032/wallet/getchainparameters'
  _globals['_WALLET'].methods_by_name['GetAssetIssueList']._loaded_options = None
  _globals['_WALLET'].methods_by_name['GetAssetIssueList']._serialized_options = b'\202\323\344\223\002;\"\031/wallet/getassetissuelist:\001*Z\033\022\031/wallet/getassetissuelist'
  _globals['_WALLET'].methods_by_name['GetPaginatedAssetIssueList']._loaded_options = None
  _globals['_WALLET'].methods_by_name['GetPaginatedAssetIssueList']._serialized_options = b'\202\323\344\223\002M\"\"/wallet/getpaginatedassetissuelist:\001*Z$\022\"/wallet/getpaginatedassetissuelist'
  _globals['_WALLET'].methods_by_name['TotalTransaction']._loaded_options = None
  _globals['_WALLET'].methods_by_name['TotalTransaction']._serialized_options = b'\202\323\344\223\0029\"\030/wallet/totaltransaction:\001*Z\032\022\030/wallet/totaltransaction'
  _globals['_WALLET'].methods_by_name['GetNextMaintenanceTime']._loaded_options = None
  _globals['_WALLET'].methods_by_name['GetNextMaintenanceTime']._serialized_options = b'\202\323\344\223\002E\"\036/wallet/getnextmaintenancetime:\001*Z \022\036/wallet/getnextmaintenancetime'
  _globals['_WALLET'].methods_by_name['GetTransactionInfoById']._loaded_options = None
  _globals['_WALLET'].methods_by_name['GetTransactionInfoById']._serialized_options = b'\202\323\344\223\002E\"\036/wallet/gettransactioninfobyid:\001*Z \022\036/wallet/gettransactioninfobyid'
  _globals['_WALLET'].methods_by_name['AccountPermissionUpdate']._loaded_options = None
  _globals['_WALLET'].methods_by_name['AccountPermissionUpdate']._serialized_options = b'\202\323\344\223\002G\"\037/wallet/accountpermissionupdate:\001*Z!\022\037/wallet/accountpermissionupdate'
  _globals['_WALLETSOLIDITY'].methods_by_name['GetAccount']._loaded_options = None
  _globals['_WALLETSOLIDITY'].methods_by_name['GetAccount']._serialized_options = b'\202\323\344\223\002=\"\032/walletsolidity/getaccount:\001*Z\034\022\032/walletsolidity/getaccount'
  _globals['_WALLETSOLIDITY'].methods_by_name['GetAccountById']._loaded_options = None
  _globals['_WALLETSOLIDITY'].methods_by_name['GetAccountById']._serialized_options = b'\202\323\344\223\002E\"\036/walletsolidity/getaccountbyid:\001*Z \022\036/walletsolidity/getaccountbyid'
  _globals['_WALLETSOLIDITY'].methods_by_name['ListWitnesses']._loaded_options = None
  _globals['_WALLETSOLIDITY'].methods_by_name['ListWitnesses']._serialized_options = b'\202\323\344\223\002C\"\035/walletsolidity/listwitnesses:\001*Z\037\022\035/walletsolidity/listwitnesses'
  _globals['_WALLETSOLIDITY'].methods_by_name['GetAssetIssueList']._loaded_options = None
  _globals['_WALLETSOLIDITY'].methods_by_name['GetAssetIssueList']._serialized_options = b'\202\323\344\223\002K\"!/walletsolidity/getassetissuelist:\001*Z#\022!/walletsolidity/getassetissuelist'
  _globals['_WALLETSOLIDITY'].methods_by_name['GetPaginatedAssetIssueList']._loaded_options = None
  _globals['_WALLETSOLIDITY'].methods_by_name['GetPaginatedAssetIssueList']._serialized_options = b'\202\323\344\223\002]\"*/walletsolidity/getpaginatedassetissuelist:\001*Z,\022*/walletsolidity/getpaginatedassetissuelist'
  _globals['_WALLETSOLIDITY'].methods_by_name['GetNowBlock']._loaded_options = None
  _globals['_WALLETSOLIDITY'].methods_by_name['GetNowBlock']._serialized_options = b'\202\323\344\223\002?\"\033/walletsolidity/getnowblock:\001*Z\035\022\033/walletsolidity/getnowblock'
  _globals['_WALLETSOLIDITY'].methods_by_name['GetBlockByNum']._loaded_options = None
  _globals['_WALLETSOLIDITY'].methods_by_name['GetBlockByNum']._serialized_options = b'\202\323\344\223\002C\"\035/walletsolidity/getblockbynum:\001*Z\037\022\035/walletsolidity/getblockbynum'
  _globals['_WALLETSOLIDITY'].methods_by_name['GetTransactionById']._loaded_options = None
  _globals['_WALLETSOLIDITY'].methods_by_name['GetTransactionById']._serialized_options = b'\202\323\344\223\002M\"\"/walletsolidity/gettransactionbyid:\001*Z$\022\"/walletsolidity/gettransactionbyid'
  _globals['_WALLETSOLIDITY'].methods_by_name['GetTransactionInfoById']._loaded_options = None
  _globals['_WALLETSOLIDITY'].methods_by_name['GetTransactionInfoById']._serialized_options = b'\202\323\344\223\002U\"&/walletsolidity/gettransactioninfobyid:\001*Z(\022&/walletsolidity/gettransactioninfobyid'
  _globals['_WALLETEXTENSION'].methods_by_name['GetTransactionsFromThis']._loaded_options = None
  _globals['_WALLETEXTENSION'].methods_by_name['GetTransactionsFromThis']._serialized_options = b'\202\323\344\223\002Y\"(/walletextension/gettransactionsfromthis:\001*Z*\022(/walletextension/gettransactionsfromthis'
  _globals['_WALLETEXTENSION'].methods_by_name['GetTransactionsToThis']._loaded_options = None
  _globals['_WALLETEXTENSION'].methods_by_name['GetTransactionsToThis']._serialized_options = b'\202\323\344\223\002U\"&/walletextension/gettransactionstothis:\001*Z(\022&/walletextension/gettransactionstothis'
  _globals['_MONITOR'].methods_by_name['GetStatsInfo']._loaded_options = None
  _globals['_MONITOR'].methods_by_name['GetStatsInfo']._serialized_options = b'\202\323\344\223\0023\"\025/monitor/getstatsinfo:\001*Z\027\022\025/monitor/getstatsinfo'
  _globals['_RETURN']._serialized_start=673
  _globals['_RETURN']._serialized_end=1101
  _globals['_RETURN_RESPONSE_CODE']._serialized_start=763
  _globals['_RETURN_RESPONSE_CODE']._serialized_end=1101
  _globals['_BLOCKREFERENCE']._serialized_start=1103
  _globals['_BLOCKREFERENCE']._serialized_end=1158
  _globals['_WITNESSLIST']._serialized_start=1160
  _globals['_WITNESSLIST']._serialized_end=1211
  _globals['_PROPOSALLIST']._serialized_start=1213
  _globals['_PROPOSALLIST']._serialized_end=1266
  _globals['_EXCHANGELIST']._serialized_start=1268
  _globals['_EXCHANGELIST']._serialized_end=1321
  _globals['_ASSETISSUELIST']._serialized_start=1323
  _globals['_ASSETISSUELIST']._serialized_end=1389
  _globals['_BLOCKLIST']._serialized_start=1391
  _globals['_BLOCKLIST']._serialized_end=1434
  _globals['_TRANSACTIONLIST']._serialized_start=1436
  _globals['_TRANSACTIONLIST']._serialized_end=1497
  _globals['_TRANSACTIONIDLIST']._serialized_start=1499
  _globals['_TRANSACTIONIDLIST']._serialized_end=1532
  _globals['_DELEGATEDRESOURCEMESSAGE']._serialized_start=1534
  _globals['_DELEGATEDRESOURCEMESSAGE']._serialized_end=1600
  _globals['_DELEGATEDRESOURCELIST']._serialized_start=1602
  _globals['_DELEGATEDRESOURCELIST']._serialized_end=1681
  _globals['_GETAVAILABLEUNFREEZECOUNTREQUESTMESSAGE']._serialized_start=1683
  _globals['_GETAVAILABLEUNFREEZECOUNTREQUESTMESSAGE']._serialized_end=1747
  _globals['_GETAVAILABLEUNFREEZECOUNTRESPONSEMESSAGE']._serialized_start=1749
  _globals['_GETAVAILABLEUNFREEZECOUNTRESPONSEMESSAGE']._serialized_end=1806
  _globals['_CANDELEGATEDMAXSIZEREQUESTMESSAGE']._serialized_start=1808
  _globals['_CANDELEGATEDMAXSIZEREQUESTMESSAGE']._serialized_end=1880
  _globals['_CANDELEGATEDMAXSIZERESPONSEMESSAGE']._serialized_start=1882
  _globals['_CANDELEGATEDMAXSIZERESPONSEMESSAGE']._serialized_end=1936
  _globals['_CANWITHDRAWUNFREEZEAMOUNTREQUESTMESSAGE']._serialized_start=1938
  _globals['_CANWITHDRAWUNFREEZEAMOUNTREQUESTMESSAGE']._serialized_end=2021
  _globals['_CANWITHDRAWUNFREEZEAMOUNTRESPONSEMESSAGE']._serialized_start=2023
  _globals['_CANWITHDRAWUNFREEZEAMOUNTRESPONSEMESSAGE']._serialized_end=2081
  _globals['_PRICESRESPONSEMESSAGE']._serialized_start=2083
  _globals['_PRICESRESPONSEMESSAGE']._serialized_end=2122
  _globals['_NODELIST']._serialized_start=2124
  _globals['_NODELIST']._serialized_end=2165
  _globals['_NODE']._serialized_start=2167
  _globals['_NODE']._serialized_end=2209
  _globals['_ADDRESS']._serialized_start=2211
  _globals['_ADDRESS']._serialized_end=2248
  _globals['_EMPTYMESSAGE']._serialized_start=2250
  _globals['_EMPTYMESSAGE']._serialized_end=2264
  _globals['_NUMBERMESSAGE']._serialized_start=2266
  _globals['_NUMBERMESSAGE']._serialized_end=2294
  _globals['_BYTESMESSAGE']._serialized_start=2296
  _globals['_BYTESMESSAGE']._serialized_end=2325
  _globals['_TIMEMESSAGE']._serialized_start=2327
  _globals['_TIMEMESSAGE']._serialized_end=2396
  _globals['_BLOCKREQ']._serialized_start=2398
  _globals['_BLOCKREQ']._serialized_end=2443
  _globals['_BLOCKLIMIT']._serialized_start=2445
  _globals['_BLOCKLIMIT']._serialized_end=2491
  _globals['_TRANSACTIONLIMIT']._serialized_start=2493
  _globals['_TRANSACTIONLIMIT']._serialized_end=2552
  _globals['_ACCOUNTPAGINATED']._serialized_start=2554
  _globals['_ACCOUNTPAGINATED']._serialized_end=2639
  _globals['_TIMEPAGINATEDMESSAGE']._serialized_start=2641
  _globals['_TIMEPAGINATEDMESSAGE']._serialized_end=2738
  _globals['_ACCOUNTNETMESSAGE']._serialized_start=2741
  _globals['_ACCOUNTNETMESSAGE']._serialized_end=3132
  _globals['_ACCOUNTNETMESSAGE_ASSETNETUSEDENTRY']._serialized_start=3027
  _globals['_ACCOUNTNETMESSAGE_ASSETNETUSEDENTRY']._serialized_end=3078
  _globals['_ACCOUNTNETMESSAGE_ASSETNETLIMITENTRY']._serialized_start=3080
  _globals['_ACCOUNTNETMESSAGE_ASSETNETLIMITENTRY']._serialized_end=3132
  _globals['_ACCOUNTRESOURCEMESSAGE']._serialized_start=3135
  _globals['_ACCOUNTRESOURCEMESSAGE']._serialized_end=3755
  _globals['_ACCOUNTRESOURCEMESSAGE_ASSETNETUSEDENTRY']._serialized_start=3027
  _globals['_ACCOUNTRESOURCEMESSAGE_ASSETNETUSEDENTRY']._serialized_end=3078
  _globals['_ACCOUNTRESOURCEMESSAGE_ASSETNETLIMITENTRY']._serialized_start=3080
  _globals['_ACCOUNTRESOURCEMESSAGE_ASSETNETLIMITENTRY']._serialized_end=3132
  _globals['_PAGINATEDMESSAGE']._serialized_start=3757
  _globals['_PAGINATEDMESSAGE']._serialized_end=3806
  _globals['_TRANSACTIONEXTENTION']._serialized_start=3809
  _globals['_TRANSACTIONEXTENTION']._serialized_end=4100
  _globals['_ESTIMATEENERGYMESSAGE']._serialized_start=4102
  _globals['_ESTIMATEENERGYMESSAGE']._serialized_end=4184
  _globals['_BLOCKEXTENTION']._serialized_start=4187
  _globals['_BLOCKEXTENTION']._serialized_end=4319
  _globals['_BLOCKLISTEXTENTION']._serialized_start=4321
  _globals['_BLOCKLISTEXTENTION']._serialized_end=4382
  _globals['_TRANSACTIONLISTEXTENTION']._serialized_start=4384
  _globals['_TRANSACTIONLISTEXTENTION']._serialized_end=4463
  _globals['_BLOCKINCREMENTALMERKLETREE']._serialized_start=4465
  _globals['_BLOCKINCREMENTALMERKLETREE']._serialized_end=4562
  _globals['_TRANSACTIONSIGNWEIGHT']._serialized_start=4565
  _globals['_TRANSACTIONSIGNWEIGHT']._serialized_end=5044
  _globals['_TRANSACTIONSIGNWEIGHT_RESULT']._serialized_start=4789
  _globals['_TRANSACTIONSIGNWEIGHT_RESULT']._serialized_end=5044
  _globals['_TRANSACTIONSIGNWEIGHT_RESULT_RESPONSE_CODE']._serialized_start=4885
  _globals['_TRANSACTIONSIGNWEIGHT_RESULT_RESPONSE_CODE']._serialized_end=5044
  _globals['_TRANSACTIONAPPROVEDLIST']._serialized_start=5047
  _globals['_TRANSACTIONAPPROVEDLIST']._serialized_end=5406
  _globals['_TRANSACTIONAPPROVEDLIST_RESULT']._serialized_start=5209
  _globals['_TRANSACTIONAPPROVEDLIST_RESULT']._serialized_end=5406
  _globals['_TRANSACTIONAPPROVEDLIST_RESULT_RESPONSE_CODE']._serialized_start=5306
  _globals['_TRANSACTIONAPPROVEDLIST_RESULT_RESPONSE_CODE']._serialized_end=5406
  _globals['_IVKDECRYPTPARAMETERS']._serialized_start=5408
  _globals['_IVKDECRYPTPARAMETERS']._serialized_end=5495
  _globals['_IVKDECRYPTANDMARKPARAMETERS']._serialized_start=5497
  _globals['_IVKDECRYPTANDMARKPARAMETERS']._serialized_end=5615
  _globals['_OVKDECRYPTPARAMETERS']._serialized_start=5617
  _globals['_OVKDECRYPTPARAMETERS']._serialized_end=5704
  _globals['_DECRYPTNOTES']._serialized_start=5707
  _globals['_DECRYPTNOTES']._serialized_end=5838
  _globals['_DECRYPTNOTES_NOTETX']._serialized_start=5771
  _globals['_DECRYPTNOTES_NOTETX']._serialized_end=5838
  _globals['_DECRYPTNOTESMARKED']._serialized_start=5841
  _globals['_DECRYPTNOTESMARKED']._serialized_end=6002
  _globals['_DECRYPTNOTESMARKED_NOTETX']._serialized_start=5917
  _globals['_DECRYPTNOTESMARKED_NOTETX']._serialized_end=6002
  _globals['_NOTE']._serialized_start=6004
  _globals['_NOTE']._serialized_end=6077
  _globals['_SPENDNOTE']._serialized_start=6079
  _globals['_SPENDNOTE']._serialized_end=6202
  _globals['_RECEIVENOTE']._serialized_start=6204
  _globals['_RECEIVENOTE']._serialized_end=6247
  _globals['_PRIVATEPARAMETERS']._serialized_start=6250
  _globals['_PRIVATEPARAMETERS']._serialized_end=6527
  _globals['_PRIVATEPARAMETERSWITHOUTASK']._serialized_start=6530
  _globals['_PRIVATEPARAMETERSWITHOUTASK']._serialized_end=6816
  _globals['_SPENDAUTHSIGPARAMETERS']._serialized_start=6818
  _globals['_SPENDAUTHSIGPARAMETERS']._serialized_end=6887
  _globals['_NFPARAMETERS']._serialized_start=6889
  _globals['_NFPARAMETERS']._serialized_end=7010
  _globals['_EXPANDEDSPENDINGKEYMESSAGE']._serialized_start=7012
  _globals['_EXPANDEDSPENDINGKEYMESSAGE']._serialized_end=7079
  _globals['_VIEWINGKEYMESSAGE']._serialized_start=7081
  _globals['_VIEWINGKEYMESSAGE']._serialized_end=7124
  _globals['_INCOMINGVIEWINGKEYMESSAGE']._serialized_start=7126
  _globals['_INCOMINGVIEWINGKEYMESSAGE']._serialized_end=7166
  _globals['_DIVERSIFIERMESSAGE']._serialized_start=7168
  _globals['_DIVERSIFIERMESSAGE']._serialized_end=7199
  _globals['_INCOMINGVIEWINGKEYDIVERSIFIERMESSAGE']._serialized_start=7202
  _globals['_INCOMINGVIEWINGKEYDIVERSIFIERMESSAGE']._serialized_end=7331
  _globals['_PAYMENTADDRESSMESSAGE']._serialized_start=7333
  _globals['_PAYMENTADDRESSMESSAGE']._serialized_end=7435
  _globals['_SHIELDEDADDRESSINFO']._serialized_start=7438
  _globals['_SHIELDEDADDRESSINFO']._serialized_end=7596
  _globals['_NOTEPARAMETERS']._serialized_start=7598
  _globals['_NOTEPARAMETERS']._serialized_end=7697
  _globals['_SPENDRESULT']._serialized_start=7699
  _globals['_SPENDRESULT']._serialized_end=7745
  _globals['_TRANSACTIONINFOLIST']._serialized_start=7747
  _globals['_TRANSACTIONINFOLIST']._serialized_end=7820
  _globals['_SPENDNOTETRC20']._serialized_start=7822
  _globals['_SPENDNOTETRC20']._serialized_end=7924
  _globals['_PRIVATESHIELDEDTRC20PARAMETERS']._serialized_start=7927
  _globals['_PRIVATESHIELDEDTRC20PARAMETERS']._serialized_end=8212
  _globals['_PRIVATESHIELDEDTRC20PARAMETERSWITHOUTASK']._serialized_start=8215
  _globals['_PRIVATESHIELDEDTRC20PARAMETERSWITHOUTASK']._serialized_end=8509
  _globals['_SHIELDEDTRC20PARAMETERS']._serialized_start=8512
  _globals['_SHIELDEDTRC20PARAMETERS']._serialized_end=8756
  _globals['_IVKDECRYPTTRC20PARAMETERS']._serialized_start=8759
  _globals['_IVKDECRYPTTRC20PARAMETERS']._serialized_end=8932
  _globals['_OVKDECRYPTTRC20PARAMETERS']._serialized_start=8935
  _globals['_OVKDECRYPTTRC20PARAMETERS']._serialized_end=9084
  _globals['_DECRYPTNOTESTRC20']._serialized_start=9087
  _globals['_DECRYPTNOTESTRC20']._serialized_end=9316
  _globals['_DECRYPTNOTESTRC20_NOTETX']._serialized_start=9162
  _globals['_DECRYPTNOTESTRC20_NOTETX']._serialized_end=9316
  _globals['_NFTRC20PARAMETERS']._serialized_start=9319
  _globals['_NFTRC20PARAMETERS']._serialized_end=9451
  _globals['_NULLIFIERRESULT']._serialized_start=9453
  _globals['_NULLIFIERRESULT']._serialized_end=9488
  _globals['_SHIELDEDTRC20TRIGGERCONTRACTPARAMETERS']._serialized_start=9491
  _globals['_SHIELDEDTRC20TRIGGERCONTRACTPARAMETERS']._serialized_end=9708
  _globals['_WALLET']._serialized_start=9711
  _globals['_WALLET']._serialized_end=24597
  _globals['_WALLETSOLIDITY']._serialized_start=24600
  _globals['_WALLETSOLIDITY']._serialized_end=29103
  _globals['_WALLETEXTENSION']._serialized_start=29106
  _globals['_WALLETEXTENSION']._serialized_end=29663
  _globals['_DATABASE']._serialized_start=29666
  _globals['_DATABASE']._serialized_end=29947
  _globals['_MONITOR']._serialized_start=29950
  _globals['_MONITOR']._serialized_end=30081
  _globals['_NETWORK']._serialized_start=30083
  _globals['_NETWORK']._serialized_end=30092
# @@protoc_insertion_point(module_scope)
