# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tron_sdk_py/proto/core/contract/balance_contract.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'tron_sdk_py/proto/core/contract/balance_contract.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tron_sdk_py.proto.core.contract import common_pb2 as tron__sdk__py_dot_proto_dot_core_dot_contract_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6tron_sdk_py/proto/core/contract/balance_contract.proto\x12\x08protocol\x1a,tron_sdk_py/proto/core/contract/common.proto\"\xa3\x01\n\x15\x46reezeBalanceContract\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\x12\x16\n\x0e\x66rozen_balance\x18\x02 \x01(\x03\x12\x17\n\x0f\x66rozen_duration\x18\x03 \x01(\x03\x12(\n\x08resource\x18\n \x01(\x0e\x32\x16.protocol.ResourceCode\x12\x18\n\x10receiver_address\x18\x0f \x01(\x0c\"t\n\x17UnfreezeBalanceContract\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\x12(\n\x08resource\x18\n \x01(\x0e\x32\x16.protocol.ResourceCode\x12\x18\n\x10receiver_address\x18\x0f \x01(\x0c\"0\n\x17WithdrawBalanceContract\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\"M\n\x10TransferContract\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\x12\x12\n\nto_address\x18\x02 \x01(\x0c\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x03\"\xe3\x01\n\x17TransactionBalanceTrace\x12\x1e\n\x16transaction_identifier\x18\x01 \x01(\x0c\x12>\n\toperation\x18\x02 \x03(\x0b\x32+.protocol.TransactionBalanceTrace.Operation\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x1aJ\n\tOperation\x12\x1c\n\x14operation_identifier\x18\x01 \x01(\x03\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0c\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x03\"\xe4\x01\n\x11\x42lockBalanceTrace\x12\x45\n\x10\x62lock_identifier\x18\x01 \x01(\x0b\x32+.protocol.BlockBalanceTrace.BlockIdentifier\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12\x44\n\x19transaction_balance_trace\x18\x03 \x03(\x0b\x32!.protocol.TransactionBalanceTrace\x1a/\n\x0f\x42lockIdentifier\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x0e\n\x06number\x18\x02 \x01(\x03\"4\n\x0c\x41\x63\x63ountTrace\x12\x0f\n\x07\x62\x61lance\x18\x01 \x01(\x03\x12\x13\n\x0bplaceholder\x18\x63 \x01(\x03\"$\n\x11\x41\x63\x63ountIdentifier\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\"\x97\x01\n\x15\x41\x63\x63ountBalanceRequest\x12\x37\n\x12\x61\x63\x63ount_identifier\x18\x01 \x01(\x0b\x32\x1b.protocol.AccountIdentifier\x12\x45\n\x10\x62lock_identifier\x18\x02 \x01(\x0b\x32+.protocol.BlockBalanceTrace.BlockIdentifier\"p\n\x16\x41\x63\x63ountBalanceResponse\x12\x0f\n\x07\x62\x61lance\x18\x01 \x01(\x03\x12\x45\n\x10\x62lock_identifier\x18\x02 \x01(\x0b\x32+.protocol.BlockBalanceTrace.BlockIdentifier\"r\n\x17\x46reezeBalanceV2Contract\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\x12\x16\n\x0e\x66rozen_balance\x18\x02 \x01(\x03\x12(\n\x08resource\x18\x03 \x01(\x0e\x32\x16.protocol.ResourceCode\"v\n\x19UnfreezeBalanceV2Contract\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\x12\x18\n\x10unfreeze_balance\x18\x02 \x01(\x03\x12(\n\x08resource\x18\x03 \x01(\x0e\x32\x16.protocol.ResourceCode\"7\n\x1eWithdrawExpireUnfreezeContract\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\"\xa9\x01\n\x18\x44\x65legateResourceContract\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\x12(\n\x08resource\x18\x02 \x01(\x0e\x32\x16.protocol.ResourceCode\x12\x0f\n\x07\x62\x61lance\x18\x03 \x01(\x03\x12\x18\n\x10receiver_address\x18\x04 \x01(\x0c\x12\x0c\n\x04lock\x18\x05 \x01(\x08\x12\x13\n\x0block_period\x18\x06 \x01(\x03\"\x88\x01\n\x1aUnDelegateResourceContract\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\x12(\n\x08resource\x18\x02 \x01(\x0e\x32\x16.protocol.ResourceCode\x12\x0f\n\x07\x62\x61lance\x18\x03 \x01(\x03\x12\x18\n\x10receiver_address\x18\x04 \x01(\x0c\"4\n\x1b\x43\x61ncelAllUnfreezeV2Contract\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\x42\x45\n\x18org.tron.protos.contractZ)github.com/tronprotocol/grpc-gateway/coreb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tron_sdk_py.proto.core.contract.balance_contract_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030org.tron.protos.contractZ)github.com/tronprotocol/grpc-gateway/core'
  _globals['_FREEZEBALANCECONTRACT']._serialized_start=115
  _globals['_FREEZEBALANCECONTRACT']._serialized_end=278
  _globals['_UNFREEZEBALANCECONTRACT']._serialized_start=280
  _globals['_UNFREEZEBALANCECONTRACT']._serialized_end=396
  _globals['_WITHDRAWBALANCECONTRACT']._serialized_start=398
  _globals['_WITHDRAWBALANCECONTRACT']._serialized_end=446
  _globals['_TRANSFERCONTRACT']._serialized_start=448
  _globals['_TRANSFERCONTRACT']._serialized_end=525
  _globals['_TRANSACTIONBALANCETRACE']._serialized_start=528
  _globals['_TRANSACTIONBALANCETRACE']._serialized_end=755
  _globals['_TRANSACTIONBALANCETRACE_OPERATION']._serialized_start=681
  _globals['_TRANSACTIONBALANCETRACE_OPERATION']._serialized_end=755
  _globals['_BLOCKBALANCETRACE']._serialized_start=758
  _globals['_BLOCKBALANCETRACE']._serialized_end=986
  _globals['_BLOCKBALANCETRACE_BLOCKIDENTIFIER']._serialized_start=939
  _globals['_BLOCKBALANCETRACE_BLOCKIDENTIFIER']._serialized_end=986
  _globals['_ACCOUNTTRACE']._serialized_start=988
  _globals['_ACCOUNTTRACE']._serialized_end=1040
  _globals['_ACCOUNTIDENTIFIER']._serialized_start=1042
  _globals['_ACCOUNTIDENTIFIER']._serialized_end=1078
  _globals['_ACCOUNTBALANCEREQUEST']._serialized_start=1081
  _globals['_ACCOUNTBALANCEREQUEST']._serialized_end=1232
  _globals['_ACCOUNTBALANCERESPONSE']._serialized_start=1234
  _globals['_ACCOUNTBALANCERESPONSE']._serialized_end=1346
  _globals['_FREEZEBALANCEV2CONTRACT']._serialized_start=1348
  _globals['_FREEZEBALANCEV2CONTRACT']._serialized_end=1462
  _globals['_UNFREEZEBALANCEV2CONTRACT']._serialized_start=1464
  _globals['_UNFREEZEBALANCEV2CONTRACT']._serialized_end=1582
  _globals['_WITHDRAWEXPIREUNFREEZECONTRACT']._serialized_start=1584
  _globals['_WITHDRAWEXPIREUNFREEZECONTRACT']._serialized_end=1639
  _globals['_DELEGATERESOURCECONTRACT']._serialized_start=1642
  _globals['_DELEGATERESOURCECONTRACT']._serialized_end=1811
  _globals['_UNDELEGATERESOURCECONTRACT']._serialized_start=1814
  _globals['_UNDELEGATERESOURCECONTRACT']._serialized_end=1950
  _globals['_CANCELALLUNFREEZEV2CONTRACT']._serialized_start=1952
  _globals['_CANCELALLUNFREEZEV2CONTRACT']._serialized_end=2004
# @@protoc_insertion_point(module_scope)
