# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tron_sdk_py/proto/core/contract/market_contract.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'tron_sdk_py/proto/core/contract/market_contract.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5tron_sdk_py/proto/core/contract/market_contract.proto\x12\x08protocol\"\x96\x01\n\x17MarketSellAssetContract\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\x12\x15\n\rsell_token_id\x18\x02 \x01(\x0c\x12\x1b\n\x13sell_token_quantity\x18\x03 \x01(\x03\x12\x14\n\x0c\x62uy_token_id\x18\x04 \x01(\x0c\x12\x1a\n\x12\x62uy_token_quantity\x18\x05 \x01(\x03\"D\n\x19MarketCancelOrderContract\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\x12\x10\n\x08order_id\x18\x02 \x01(\x0c\x42\x45\n\x18org.tron.protos.contractZ)github.com/tronprotocol/grpc-gateway/coreb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tron_sdk_py.proto.core.contract.market_contract_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030org.tron.protos.contractZ)github.com/tronprotocol/grpc-gateway/core'
  _globals['_MARKETSELLASSETCONTRACT']._serialized_start=68
  _globals['_MARKETSELLASSETCONTRACT']._serialized_end=218
  _globals['_MARKETCANCELORDERCONTRACT']._serialized_start=220
  _globals['_MARKETCANCELORDERCONTRACT']._serialized_end=288
# @@protoc_insertion_point(module_scope)
