# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from tron_sdk_py.proto.api import api_pb2 as tron__sdk__py_dot_proto_dot_api_dot_api__pb2
from tron_sdk_py.proto.core import Tron_pb2 as tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2
from tron_sdk_py.proto.core.contract import account_contract_pb2 as tron__sdk__py_dot_proto_dot_core_dot_contract_dot_account__contract__pb2
from tron_sdk_py.proto.core.contract import asset_issue_contract_pb2 as tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2
from tron_sdk_py.proto.core.contract import balance_contract_pb2 as tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2
from tron_sdk_py.proto.core.contract import exchange_contract_pb2 as tron__sdk__py_dot_proto_dot_core_dot_contract_dot_exchange__contract__pb2
from tron_sdk_py.proto.core.contract import market_contract_pb2 as tron__sdk__py_dot_proto_dot_core_dot_contract_dot_market__contract__pb2
from tron_sdk_py.proto.core.contract import proposal_contract_pb2 as tron__sdk__py_dot_proto_dot_core_dot_contract_dot_proposal__contract__pb2
from tron_sdk_py.proto.core.contract import shield_contract_pb2 as tron__sdk__py_dot_proto_dot_core_dot_contract_dot_shield__contract__pb2
from tron_sdk_py.proto.core.contract import smart_contract_pb2 as tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2
from tron_sdk_py.proto.core.contract import storage_contract_pb2 as tron__sdk__py_dot_proto_dot_core_dot_contract_dot_storage__contract__pb2
from tron_sdk_py.proto.core.contract import witness_contract_pb2 as tron__sdk__py_dot_proto_dot_core_dot_contract_dot_witness__contract__pb2

GRPC_GENERATED_VERSION = '1.73.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in tron_sdk_py/proto/api/api_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class WalletStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAccount = channel.unary_unary(
                '/protocol.Wallet/GetAccount',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.FromString,
                _registered_method=True)
        self.GetAccountById = channel.unary_unary(
                '/protocol.Wallet/GetAccountById',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.FromString,
                _registered_method=True)
        self.GetAccountBalance = channel.unary_unary(
                '/protocol.Wallet/GetAccountBalance',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.AccountBalanceRequest.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.AccountBalanceResponse.FromString,
                _registered_method=True)
        self.GetBlockBalanceTrace = channel.unary_unary(
                '/protocol.Wallet/GetBlockBalanceTrace',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.BlockBalanceTrace.BlockIdentifier.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.BlockBalanceTrace.FromString,
                _registered_method=True)
        self.CreateTransaction = channel.unary_unary(
                '/protocol.Wallet/CreateTransaction',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.TransferContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                _registered_method=True)
        self.CreateTransaction2 = channel.unary_unary(
                '/protocol.Wallet/CreateTransaction2',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.TransferContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.BroadcastTransaction = channel.unary_unary(
                '/protocol.Wallet/BroadcastTransaction',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.Return.FromString,
                _registered_method=True)
        self.UpdateAccount = channel.unary_unary(
                '/protocol.Wallet/UpdateAccount',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_account__contract__pb2.AccountUpdateContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                _registered_method=True)
        self.SetAccountId = channel.unary_unary(
                '/protocol.Wallet/SetAccountId',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_account__contract__pb2.SetAccountIdContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                _registered_method=True)
        self.UpdateAccount2 = channel.unary_unary(
                '/protocol.Wallet/UpdateAccount2',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_account__contract__pb2.AccountUpdateContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.VoteWitnessAccount = channel.unary_unary(
                '/protocol.Wallet/VoteWitnessAccount',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_witness__contract__pb2.VoteWitnessContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                _registered_method=True)
        self.UpdateSetting = channel.unary_unary(
                '/protocol.Wallet/UpdateSetting',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.UpdateSettingContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.UpdateEnergyLimit = channel.unary_unary(
                '/protocol.Wallet/UpdateEnergyLimit',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.UpdateEnergyLimitContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.VoteWitnessAccount2 = channel.unary_unary(
                '/protocol.Wallet/VoteWitnessAccount2',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_witness__contract__pb2.VoteWitnessContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.CreateAssetIssue = channel.unary_unary(
                '/protocol.Wallet/CreateAssetIssue',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.AssetIssueContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                _registered_method=True)
        self.CreateAssetIssue2 = channel.unary_unary(
                '/protocol.Wallet/CreateAssetIssue2',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.AssetIssueContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.UpdateWitness = channel.unary_unary(
                '/protocol.Wallet/UpdateWitness',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_witness__contract__pb2.WitnessUpdateContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                _registered_method=True)
        self.UpdateWitness2 = channel.unary_unary(
                '/protocol.Wallet/UpdateWitness2',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_witness__contract__pb2.WitnessUpdateContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.CreateAccount = channel.unary_unary(
                '/protocol.Wallet/CreateAccount',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_account__contract__pb2.AccountCreateContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                _registered_method=True)
        self.CreateAccount2 = channel.unary_unary(
                '/protocol.Wallet/CreateAccount2',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_account__contract__pb2.AccountCreateContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.CreateWitness = channel.unary_unary(
                '/protocol.Wallet/CreateWitness',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_witness__contract__pb2.WitnessCreateContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                _registered_method=True)
        self.CreateWitness2 = channel.unary_unary(
                '/protocol.Wallet/CreateWitness2',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_witness__contract__pb2.WitnessCreateContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.TransferAsset = channel.unary_unary(
                '/protocol.Wallet/TransferAsset',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.TransferAssetContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                _registered_method=True)
        self.TransferAsset2 = channel.unary_unary(
                '/protocol.Wallet/TransferAsset2',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.TransferAssetContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.ParticipateAssetIssue = channel.unary_unary(
                '/protocol.Wallet/ParticipateAssetIssue',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.ParticipateAssetIssueContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                _registered_method=True)
        self.ParticipateAssetIssue2 = channel.unary_unary(
                '/protocol.Wallet/ParticipateAssetIssue2',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.ParticipateAssetIssueContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.FreezeBalance = channel.unary_unary(
                '/protocol.Wallet/FreezeBalance',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.FreezeBalanceContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                _registered_method=True)
        self.FreezeBalance2 = channel.unary_unary(
                '/protocol.Wallet/FreezeBalance2',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.FreezeBalanceContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.FreezeBalanceV2 = channel.unary_unary(
                '/protocol.Wallet/FreezeBalanceV2',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.FreezeBalanceV2Contract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.UnfreezeBalance = channel.unary_unary(
                '/protocol.Wallet/UnfreezeBalance',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.UnfreezeBalanceContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                _registered_method=True)
        self.UnfreezeBalance2 = channel.unary_unary(
                '/protocol.Wallet/UnfreezeBalance2',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.UnfreezeBalanceContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.UnfreezeBalanceV2 = channel.unary_unary(
                '/protocol.Wallet/UnfreezeBalanceV2',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.UnfreezeBalanceV2Contract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.UnfreezeAsset = channel.unary_unary(
                '/protocol.Wallet/UnfreezeAsset',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.UnfreezeAssetContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                _registered_method=True)
        self.UnfreezeAsset2 = channel.unary_unary(
                '/protocol.Wallet/UnfreezeAsset2',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.UnfreezeAssetContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.WithdrawBalance = channel.unary_unary(
                '/protocol.Wallet/WithdrawBalance',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.WithdrawBalanceContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                _registered_method=True)
        self.WithdrawBalance2 = channel.unary_unary(
                '/protocol.Wallet/WithdrawBalance2',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.WithdrawBalanceContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.WithdrawExpireUnfreeze = channel.unary_unary(
                '/protocol.Wallet/WithdrawExpireUnfreeze',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.WithdrawExpireUnfreezeContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.DelegateResource = channel.unary_unary(
                '/protocol.Wallet/DelegateResource',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.DelegateResourceContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.UnDelegateResource = channel.unary_unary(
                '/protocol.Wallet/UnDelegateResource',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.UnDelegateResourceContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.CancelAllUnfreezeV2 = channel.unary_unary(
                '/protocol.Wallet/CancelAllUnfreezeV2',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.CancelAllUnfreezeV2Contract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.UpdateAsset = channel.unary_unary(
                '/protocol.Wallet/UpdateAsset',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.UpdateAssetContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                _registered_method=True)
        self.UpdateAsset2 = channel.unary_unary(
                '/protocol.Wallet/UpdateAsset2',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.UpdateAssetContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.ProposalCreate = channel.unary_unary(
                '/protocol.Wallet/ProposalCreate',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_proposal__contract__pb2.ProposalCreateContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.ProposalApprove = channel.unary_unary(
                '/protocol.Wallet/ProposalApprove',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_proposal__contract__pb2.ProposalApproveContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.ProposalDelete = channel.unary_unary(
                '/protocol.Wallet/ProposalDelete',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_proposal__contract__pb2.ProposalDeleteContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.BuyStorage = channel.unary_unary(
                '/protocol.Wallet/BuyStorage',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_storage__contract__pb2.BuyStorageContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.BuyStorageBytes = channel.unary_unary(
                '/protocol.Wallet/BuyStorageBytes',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_storage__contract__pb2.BuyStorageBytesContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.SellStorage = channel.unary_unary(
                '/protocol.Wallet/SellStorage',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_storage__contract__pb2.SellStorageContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.ExchangeCreate = channel.unary_unary(
                '/protocol.Wallet/ExchangeCreate',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_exchange__contract__pb2.ExchangeCreateContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.ExchangeInject = channel.unary_unary(
                '/protocol.Wallet/ExchangeInject',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_exchange__contract__pb2.ExchangeInjectContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.ExchangeWithdraw = channel.unary_unary(
                '/protocol.Wallet/ExchangeWithdraw',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_exchange__contract__pb2.ExchangeWithdrawContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.ExchangeTransaction = channel.unary_unary(
                '/protocol.Wallet/ExchangeTransaction',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_exchange__contract__pb2.ExchangeTransactionContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.MarketSellAsset = channel.unary_unary(
                '/protocol.Wallet/MarketSellAsset',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_market__contract__pb2.MarketSellAssetContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.MarketCancelOrder = channel.unary_unary(
                '/protocol.Wallet/MarketCancelOrder',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_market__contract__pb2.MarketCancelOrderContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.GetMarketOrderById = channel.unary_unary(
                '/protocol.Wallet/GetMarketOrderById',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrder.FromString,
                _registered_method=True)
        self.GetMarketOrderByAccount = channel.unary_unary(
                '/protocol.Wallet/GetMarketOrderByAccount',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderList.FromString,
                _registered_method=True)
        self.GetMarketPriceByPair = channel.unary_unary(
                '/protocol.Wallet/GetMarketPriceByPair',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderPair.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketPriceList.FromString,
                _registered_method=True)
        self.GetMarketOrderListByPair = channel.unary_unary(
                '/protocol.Wallet/GetMarketOrderListByPair',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderPair.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderList.FromString,
                _registered_method=True)
        self.GetMarketPairList = channel.unary_unary(
                '/protocol.Wallet/GetMarketPairList',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderPairList.FromString,
                _registered_method=True)
        self.ListNodes = channel.unary_unary(
                '/protocol.Wallet/ListNodes',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NodeList.FromString,
                _registered_method=True)
        self.GetAssetIssueByAccount = channel.unary_unary(
                '/protocol.Wallet/GetAssetIssueByAccount',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AssetIssueList.FromString,
                _registered_method=True)
        self.GetAccountNet = channel.unary_unary(
                '/protocol.Wallet/GetAccountNet',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AccountNetMessage.FromString,
                _registered_method=True)
        self.GetAccountResource = channel.unary_unary(
                '/protocol.Wallet/GetAccountResource',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AccountResourceMessage.FromString,
                _registered_method=True)
        self.GetAssetIssueByName = channel.unary_unary(
                '/protocol.Wallet/GetAssetIssueByName',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.AssetIssueContract.FromString,
                _registered_method=True)
        self.GetAssetIssueListByName = channel.unary_unary(
                '/protocol.Wallet/GetAssetIssueListByName',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AssetIssueList.FromString,
                _registered_method=True)
        self.GetAssetIssueById = channel.unary_unary(
                '/protocol.Wallet/GetAssetIssueById',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.AssetIssueContract.FromString,
                _registered_method=True)
        self.GetNowBlock = channel.unary_unary(
                '/protocol.Wallet/GetNowBlock',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Block.FromString,
                _registered_method=True)
        self.GetNowBlock2 = channel.unary_unary(
                '/protocol.Wallet/GetNowBlock2',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockExtention.FromString,
                _registered_method=True)
        self.GetBlockByNum = channel.unary_unary(
                '/protocol.Wallet/GetBlockByNum',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Block.FromString,
                _registered_method=True)
        self.GetBlockByNum2 = channel.unary_unary(
                '/protocol.Wallet/GetBlockByNum2',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockExtention.FromString,
                _registered_method=True)
        self.GetTransactionCountByBlockNum = channel.unary_unary(
                '/protocol.Wallet/GetTransactionCountByBlockNum',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
                _registered_method=True)
        self.GetBlockById = channel.unary_unary(
                '/protocol.Wallet/GetBlockById',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Block.FromString,
                _registered_method=True)
        self.GetBlockByLimitNext = channel.unary_unary(
                '/protocol.Wallet/GetBlockByLimitNext',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockLimit.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockList.FromString,
                _registered_method=True)
        self.GetBlockByLimitNext2 = channel.unary_unary(
                '/protocol.Wallet/GetBlockByLimitNext2',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockLimit.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockListExtention.FromString,
                _registered_method=True)
        self.GetBlockByLatestNum = channel.unary_unary(
                '/protocol.Wallet/GetBlockByLatestNum',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockList.FromString,
                _registered_method=True)
        self.GetBlockByLatestNum2 = channel.unary_unary(
                '/protocol.Wallet/GetBlockByLatestNum2',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockListExtention.FromString,
                _registered_method=True)
        self.GetTransactionById = channel.unary_unary(
                '/protocol.Wallet/GetTransactionById',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                _registered_method=True)
        self.DeployContract = channel.unary_unary(
                '/protocol.Wallet/DeployContract',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.CreateSmartContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.GetContract = channel.unary_unary(
                '/protocol.Wallet/GetContract',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.SmartContract.FromString,
                _registered_method=True)
        self.GetContractInfo = channel.unary_unary(
                '/protocol.Wallet/GetContractInfo',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.SmartContractDataWrapper.FromString,
                _registered_method=True)
        self.TriggerContract = channel.unary_unary(
                '/protocol.Wallet/TriggerContract',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.TriggerSmartContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.TriggerConstantContract = channel.unary_unary(
                '/protocol.Wallet/TriggerConstantContract',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.TriggerSmartContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.EstimateEnergy = channel.unary_unary(
                '/protocol.Wallet/EstimateEnergy',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.TriggerSmartContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EstimateEnergyMessage.FromString,
                _registered_method=True)
        self.ClearContractABI = channel.unary_unary(
                '/protocol.Wallet/ClearContractABI',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.ClearABIContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.ListWitnesses = channel.unary_unary(
                '/protocol.Wallet/ListWitnesses',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.WitnessList.FromString,
                _registered_method=True)
        self.GetDelegatedResource = channel.unary_unary(
                '/protocol.Wallet/GetDelegatedResource',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceList.FromString,
                _registered_method=True)
        self.GetDelegatedResourceV2 = channel.unary_unary(
                '/protocol.Wallet/GetDelegatedResourceV2',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceList.FromString,
                _registered_method=True)
        self.GetDelegatedResourceAccountIndex = channel.unary_unary(
                '/protocol.Wallet/GetDelegatedResourceAccountIndex',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.DelegatedResourceAccountIndex.FromString,
                _registered_method=True)
        self.GetDelegatedResourceAccountIndexV2 = channel.unary_unary(
                '/protocol.Wallet/GetDelegatedResourceAccountIndexV2',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.DelegatedResourceAccountIndex.FromString,
                _registered_method=True)
        self.GetCanDelegatedMaxSize = channel.unary_unary(
                '/protocol.Wallet/GetCanDelegatedMaxSize',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanDelegatedMaxSizeRequestMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanDelegatedMaxSizeResponseMessage.FromString,
                _registered_method=True)
        self.GetAvailableUnfreezeCount = channel.unary_unary(
                '/protocol.Wallet/GetAvailableUnfreezeCount',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.GetAvailableUnfreezeCountRequestMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.GetAvailableUnfreezeCountResponseMessage.FromString,
                _registered_method=True)
        self.GetCanWithdrawUnfreezeAmount = channel.unary_unary(
                '/protocol.Wallet/GetCanWithdrawUnfreezeAmount',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanWithdrawUnfreezeAmountRequestMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanWithdrawUnfreezeAmountResponseMessage.FromString,
                _registered_method=True)
        self.ListProposals = channel.unary_unary(
                '/protocol.Wallet/ListProposals',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ProposalList.FromString,
                _registered_method=True)
        self.GetPaginatedProposalList = channel.unary_unary(
                '/protocol.Wallet/GetPaginatedProposalList',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PaginatedMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ProposalList.FromString,
                _registered_method=True)
        self.GetProposalById = channel.unary_unary(
                '/protocol.Wallet/GetProposalById',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Proposal.FromString,
                _registered_method=True)
        self.ListExchanges = channel.unary_unary(
                '/protocol.Wallet/ListExchanges',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ExchangeList.FromString,
                _registered_method=True)
        self.GetPaginatedExchangeList = channel.unary_unary(
                '/protocol.Wallet/GetPaginatedExchangeList',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PaginatedMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ExchangeList.FromString,
                _registered_method=True)
        self.GetExchangeById = channel.unary_unary(
                '/protocol.Wallet/GetExchangeById',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Exchange.FromString,
                _registered_method=True)
        self.GetChainParameters = channel.unary_unary(
                '/protocol.Wallet/GetChainParameters',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.ChainParameters.FromString,
                _registered_method=True)
        self.GetAssetIssueList = channel.unary_unary(
                '/protocol.Wallet/GetAssetIssueList',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AssetIssueList.FromString,
                _registered_method=True)
        self.GetPaginatedAssetIssueList = channel.unary_unary(
                '/protocol.Wallet/GetPaginatedAssetIssueList',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PaginatedMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AssetIssueList.FromString,
                _registered_method=True)
        self.TotalTransaction = channel.unary_unary(
                '/protocol.Wallet/TotalTransaction',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
                _registered_method=True)
        self.GetNextMaintenanceTime = channel.unary_unary(
                '/protocol.Wallet/GetNextMaintenanceTime',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
                _registered_method=True)
        self.GetTransactionInfoById = channel.unary_unary(
                '/protocol.Wallet/GetTransactionInfoById',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.TransactionInfo.FromString,
                _registered_method=True)
        self.AccountPermissionUpdate = channel.unary_unary(
                '/protocol.Wallet/AccountPermissionUpdate',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_account__contract__pb2.AccountPermissionUpdateContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.GetTransactionSignWeight = channel.unary_unary(
                '/protocol.Wallet/GetTransactionSignWeight',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionSignWeight.FromString,
                _registered_method=True)
        self.GetTransactionApprovedList = channel.unary_unary(
                '/protocol.Wallet/GetTransactionApprovedList',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionApprovedList.FromString,
                _registered_method=True)
        self.GetNodeInfo = channel.unary_unary(
                '/protocol.Wallet/GetNodeInfo',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.NodeInfo.FromString,
                _registered_method=True)
        self.GetRewardInfo = channel.unary_unary(
                '/protocol.Wallet/GetRewardInfo',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
                _registered_method=True)
        self.GetBrokerageInfo = channel.unary_unary(
                '/protocol.Wallet/GetBrokerageInfo',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
                _registered_method=True)
        self.UpdateBrokerage = channel.unary_unary(
                '/protocol.Wallet/UpdateBrokerage',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_storage__contract__pb2.UpdateBrokerageContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.CreateShieldedTransaction = channel.unary_unary(
                '/protocol.Wallet/CreateShieldedTransaction',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PrivateParameters.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.GetMerkleTreeVoucherInfo = channel.unary_unary(
                '/protocol.Wallet/GetMerkleTreeVoucherInfo',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_shield__contract__pb2.OutputPointInfo.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_shield__contract__pb2.IncrementalMerkleVoucherInfo.FromString,
                _registered_method=True)
        self.ScanNoteByIvk = channel.unary_unary(
                '/protocol.Wallet/ScanNoteByIvk',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IvkDecryptParameters.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotes.FromString,
                _registered_method=True)
        self.ScanAndMarkNoteByIvk = channel.unary_unary(
                '/protocol.Wallet/ScanAndMarkNoteByIvk',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IvkDecryptAndMarkParameters.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotesMarked.FromString,
                _registered_method=True)
        self.ScanNoteByOvk = channel.unary_unary(
                '/protocol.Wallet/ScanNoteByOvk',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.OvkDecryptParameters.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotes.FromString,
                _registered_method=True)
        self.GetSpendingKey = channel.unary_unary(
                '/protocol.Wallet/GetSpendingKey',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                _registered_method=True)
        self.GetExpandedSpendingKey = channel.unary_unary(
                '/protocol.Wallet/GetExpandedSpendingKey',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ExpandedSpendingKeyMessage.FromString,
                _registered_method=True)
        self.GetAkFromAsk = channel.unary_unary(
                '/protocol.Wallet/GetAkFromAsk',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                _registered_method=True)
        self.GetNkFromNsk = channel.unary_unary(
                '/protocol.Wallet/GetNkFromNsk',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                _registered_method=True)
        self.GetIncomingViewingKey = channel.unary_unary(
                '/protocol.Wallet/GetIncomingViewingKey',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ViewingKeyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IncomingViewingKeyMessage.FromString,
                _registered_method=True)
        self.GetDiversifier = channel.unary_unary(
                '/protocol.Wallet/GetDiversifier',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DiversifierMessage.FromString,
                _registered_method=True)
        self.GetNewShieldedAddress = channel.unary_unary(
                '/protocol.Wallet/GetNewShieldedAddress',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ShieldedAddressInfo.FromString,
                _registered_method=True)
        self.GetZenPaymentAddress = channel.unary_unary(
                '/protocol.Wallet/GetZenPaymentAddress',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IncomingViewingKeyDiversifierMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PaymentAddressMessage.FromString,
                _registered_method=True)
        self.GetRcm = channel.unary_unary(
                '/protocol.Wallet/GetRcm',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                _registered_method=True)
        self.IsSpend = channel.unary_unary(
                '/protocol.Wallet/IsSpend',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NoteParameters.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.SpendResult.FromString,
                _registered_method=True)
        self.CreateShieldedTransactionWithoutSpendAuthSig = channel.unary_unary(
                '/protocol.Wallet/CreateShieldedTransactionWithoutSpendAuthSig',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PrivateParametersWithoutAsk.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.GetShieldTransactionHash = channel.unary_unary(
                '/protocol.Wallet/GetShieldTransactionHash',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                _registered_method=True)
        self.CreateSpendAuthSig = channel.unary_unary(
                '/protocol.Wallet/CreateSpendAuthSig',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.SpendAuthSigParameters.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                _registered_method=True)
        self.CreateShieldNullifier = channel.unary_unary(
                '/protocol.Wallet/CreateShieldNullifier',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NfParameters.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                _registered_method=True)
        self.CreateShieldedContractParameters = channel.unary_unary(
                '/protocol.Wallet/CreateShieldedContractParameters',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PrivateShieldedTRC20Parameters.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ShieldedTRC20Parameters.FromString,
                _registered_method=True)
        self.CreateShieldedContractParametersWithoutAsk = channel.unary_unary(
                '/protocol.Wallet/CreateShieldedContractParametersWithoutAsk',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PrivateShieldedTRC20ParametersWithoutAsk.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ShieldedTRC20Parameters.FromString,
                _registered_method=True)
        self.ScanShieldedTRC20NotesByIvk = channel.unary_unary(
                '/protocol.Wallet/ScanShieldedTRC20NotesByIvk',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IvkDecryptTRC20Parameters.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotesTRC20.FromString,
                _registered_method=True)
        self.ScanShieldedTRC20NotesByOvk = channel.unary_unary(
                '/protocol.Wallet/ScanShieldedTRC20NotesByOvk',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.OvkDecryptTRC20Parameters.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotesTRC20.FromString,
                _registered_method=True)
        self.IsShieldedTRC20ContractNoteSpent = channel.unary_unary(
                '/protocol.Wallet/IsShieldedTRC20ContractNoteSpent',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NfTRC20Parameters.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NullifierResult.FromString,
                _registered_method=True)
        self.GetTriggerInputForShieldedTRC20Contract = channel.unary_unary(
                '/protocol.Wallet/GetTriggerInputForShieldedTRC20Contract',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ShieldedTRC20TriggerContractParameters.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                _registered_method=True)
        self.CreateCommonTransaction = channel.unary_unary(
                '/protocol.Wallet/CreateCommonTransaction',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.GetTransactionInfoByBlockNum = channel.unary_unary(
                '/protocol.Wallet/GetTransactionInfoByBlockNum',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionInfoList.FromString,
                _registered_method=True)
        self.GetBurnTrx = channel.unary_unary(
                '/protocol.Wallet/GetBurnTrx',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
                _registered_method=True)
        self.GetTransactionFromPending = channel.unary_unary(
                '/protocol.Wallet/GetTransactionFromPending',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                _registered_method=True)
        self.GetTransactionListFromPending = channel.unary_unary(
                '/protocol.Wallet/GetTransactionListFromPending',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionIdList.FromString,
                _registered_method=True)
        self.GetPendingSize = channel.unary_unary(
                '/protocol.Wallet/GetPendingSize',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
                _registered_method=True)
        self.GetBlock = channel.unary_unary(
                '/protocol.Wallet/GetBlock',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockReq.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockExtention.FromString,
                _registered_method=True)
        self.GetBandwidthPrices = channel.unary_unary(
                '/protocol.Wallet/GetBandwidthPrices',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PricesResponseMessage.FromString,
                _registered_method=True)
        self.GetEnergyPrices = channel.unary_unary(
                '/protocol.Wallet/GetEnergyPrices',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PricesResponseMessage.FromString,
                _registered_method=True)
        self.GetMemoFee = channel.unary_unary(
                '/protocol.Wallet/GetMemoFee',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PricesResponseMessage.FromString,
                _registered_method=True)


class WalletServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccountById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccountBalance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockBalanceTrace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTransaction(self, request, context):
        """Please use CreateTransaction2 instead of this function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTransaction2(self, request, context):
        """Use this function instead of CreateTransaction.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BroadcastTransaction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccount(self, request, context):
        """Please use UpdateAccount2 instead of this function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAccountId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccount2(self, request, context):
        """Use this function instead of UpdateAccount.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VoteWitnessAccount(self, request, context):
        """Please use VoteWitnessAccount2 instead of this function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSetting(self, request, context):
        """modify the consume_user_resource_percent
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEnergyLimit(self, request, context):
        """modify the energy_limit
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VoteWitnessAccount2(self, request, context):
        """Use this function instead of VoteWitnessAccount.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAssetIssue(self, request, context):
        """Please use CreateAssetIssue2 instead of this function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAssetIssue2(self, request, context):
        """Use this function instead of CreateAssetIssue.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateWitness(self, request, context):
        """Please use UpdateWitness2 instead of this function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateWitness2(self, request, context):
        """Use this function instead of UpdateWitness.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAccount(self, request, context):
        """Please use CreateAccount2 instead of this function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAccount2(self, request, context):
        """Use this function instead of CreateAccount.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateWitness(self, request, context):
        """Please use CreateWitness2 instead of this function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateWitness2(self, request, context):
        """Use this function instead of CreateWitness.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TransferAsset(self, request, context):
        """Please use TransferAsset2 instead of this function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TransferAsset2(self, request, context):
        """Use this function instead of TransferAsset.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ParticipateAssetIssue(self, request, context):
        """Please use ParticipateAssetIssue2 instead of this function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ParticipateAssetIssue2(self, request, context):
        """Use this function instead of ParticipateAssetIssue.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FreezeBalance(self, request, context):
        """Please use FreezeBalance2 instead of this function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FreezeBalance2(self, request, context):
        """Use this function instead of FreezeBalance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FreezeBalanceV2(self, request, context):
        """Use this function when FreezeBalanceV2.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnfreezeBalance(self, request, context):
        """Please use UnfreezeBalance2 instead of this function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnfreezeBalance2(self, request, context):
        """Use this function instead of UnfreezeBalance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnfreezeBalanceV2(self, request, context):
        """Use this function when UnfreezeBalanceV2.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnfreezeAsset(self, request, context):
        """Please use UnfreezeAsset2 instead of this function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnfreezeAsset2(self, request, context):
        """Use this function instead of UnfreezeAsset.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WithdrawBalance(self, request, context):
        """Please use WithdrawBalance2 instead of this function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WithdrawBalance2(self, request, context):
        """Use this function instead of WithdrawBalance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WithdrawExpireUnfreeze(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DelegateResource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnDelegateResource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelAllUnfreezeV2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAsset(self, request, context):
        """Please use UpdateAsset2 instead of this function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAsset2(self, request, context):
        """Use this function instead of UpdateAsset.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProposalCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProposalApprove(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProposalDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BuyStorage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BuyStorageBytes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SellStorage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExchangeCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExchangeInject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExchangeWithdraw(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExchangeTransaction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MarketSellAsset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MarketCancelOrder(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMarketOrderById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMarketOrderByAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMarketPriceByPair(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMarketOrderListByPair(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMarketPairList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNodes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAssetIssueByAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccountNet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccountResource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAssetIssueByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAssetIssueListByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAssetIssueById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNowBlock(self, request, context):
        """Please use GetNowBlock2 instead of this function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNowBlock2(self, request, context):
        """Use this function instead of GetNowBlock.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockByNum(self, request, context):
        """Please use GetBlockByNum2 instead of this function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockByNum2(self, request, context):
        """Use this function instead of GetBlockByNum.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionCountByBlockNum(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockByLimitNext(self, request, context):
        """Please use GetBlockByLimitNext2 instead of this function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockByLimitNext2(self, request, context):
        """Use this function instead of GetBlockByLimitNext.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockByLatestNum(self, request, context):
        """Please use GetBlockByLatestNum2 instead of this function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockByLatestNum2(self, request, context):
        """Use this function instead of GetBlockByLatestNum.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetContractInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerConstantContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EstimateEnergy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearContractABI(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListWitnesses(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDelegatedResource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDelegatedResourceV2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDelegatedResourceAccountIndex(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDelegatedResourceAccountIndexV2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCanDelegatedMaxSize(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAvailableUnfreezeCount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCanWithdrawUnfreezeAmount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListProposals(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPaginatedProposalList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProposalById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListExchanges(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPaginatedExchangeList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExchangeById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetChainParameters(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAssetIssueList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPaginatedAssetIssueList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TotalTransaction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNextMaintenanceTime(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionInfoById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AccountPermissionUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionSignWeight(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionApprovedList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNodeInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRewardInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBrokerageInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateBrokerage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateShieldedTransaction(self, request, context):
        """for shiededTransaction
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMerkleTreeVoucherInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScanNoteByIvk(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScanAndMarkNoteByIvk(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScanNoteByOvk(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSpendingKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExpandedSpendingKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAkFromAsk(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNkFromNsk(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIncomingViewingKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDiversifier(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNewShieldedAddress(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetZenPaymentAddress(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRcm(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsSpend(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateShieldedTransactionWithoutSpendAuthSig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetShieldTransactionHash(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSpendAuthSig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateShieldNullifier(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateShieldedContractParameters(self, request, context):
        """for shielded contract
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateShieldedContractParametersWithoutAsk(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScanShieldedTRC20NotesByIvk(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScanShieldedTRC20NotesByOvk(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsShieldedTRC20ContractNoteSpent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTriggerInputForShieldedTRC20Contract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateCommonTransaction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionInfoByBlockNum(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBurnTrx(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionFromPending(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionListFromPending(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPendingSize(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlock(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBandwidthPrices(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEnergyPrices(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMemoFee(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WalletServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccount,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.SerializeToString,
            ),
            'GetAccountById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccountById,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.SerializeToString,
            ),
            'GetAccountBalance': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccountBalance,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.AccountBalanceRequest.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.AccountBalanceResponse.SerializeToString,
            ),
            'GetBlockBalanceTrace': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockBalanceTrace,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.BlockBalanceTrace.BlockIdentifier.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.BlockBalanceTrace.SerializeToString,
            ),
            'CreateTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTransaction,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.TransferContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            ),
            'CreateTransaction2': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTransaction2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.TransferContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'BroadcastTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.BroadcastTransaction,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.Return.SerializeToString,
            ),
            'UpdateAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccount,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_account__contract__pb2.AccountUpdateContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            ),
            'SetAccountId': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAccountId,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_account__contract__pb2.SetAccountIdContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            ),
            'UpdateAccount2': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccount2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_account__contract__pb2.AccountUpdateContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'VoteWitnessAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.VoteWitnessAccount,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_witness__contract__pb2.VoteWitnessContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            ),
            'UpdateSetting': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSetting,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.UpdateSettingContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'UpdateEnergyLimit': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEnergyLimit,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.UpdateEnergyLimitContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'VoteWitnessAccount2': grpc.unary_unary_rpc_method_handler(
                    servicer.VoteWitnessAccount2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_witness__contract__pb2.VoteWitnessContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'CreateAssetIssue': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAssetIssue,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.AssetIssueContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            ),
            'CreateAssetIssue2': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAssetIssue2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.AssetIssueContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'UpdateWitness': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateWitness,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_witness__contract__pb2.WitnessUpdateContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            ),
            'UpdateWitness2': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateWitness2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_witness__contract__pb2.WitnessUpdateContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'CreateAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAccount,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_account__contract__pb2.AccountCreateContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            ),
            'CreateAccount2': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAccount2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_account__contract__pb2.AccountCreateContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'CreateWitness': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateWitness,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_witness__contract__pb2.WitnessCreateContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            ),
            'CreateWitness2': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateWitness2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_witness__contract__pb2.WitnessCreateContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'TransferAsset': grpc.unary_unary_rpc_method_handler(
                    servicer.TransferAsset,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.TransferAssetContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            ),
            'TransferAsset2': grpc.unary_unary_rpc_method_handler(
                    servicer.TransferAsset2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.TransferAssetContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'ParticipateAssetIssue': grpc.unary_unary_rpc_method_handler(
                    servicer.ParticipateAssetIssue,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.ParticipateAssetIssueContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            ),
            'ParticipateAssetIssue2': grpc.unary_unary_rpc_method_handler(
                    servicer.ParticipateAssetIssue2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.ParticipateAssetIssueContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'FreezeBalance': grpc.unary_unary_rpc_method_handler(
                    servicer.FreezeBalance,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.FreezeBalanceContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            ),
            'FreezeBalance2': grpc.unary_unary_rpc_method_handler(
                    servicer.FreezeBalance2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.FreezeBalanceContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'FreezeBalanceV2': grpc.unary_unary_rpc_method_handler(
                    servicer.FreezeBalanceV2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.FreezeBalanceV2Contract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'UnfreezeBalance': grpc.unary_unary_rpc_method_handler(
                    servicer.UnfreezeBalance,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.UnfreezeBalanceContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            ),
            'UnfreezeBalance2': grpc.unary_unary_rpc_method_handler(
                    servicer.UnfreezeBalance2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.UnfreezeBalanceContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'UnfreezeBalanceV2': grpc.unary_unary_rpc_method_handler(
                    servicer.UnfreezeBalanceV2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.UnfreezeBalanceV2Contract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'UnfreezeAsset': grpc.unary_unary_rpc_method_handler(
                    servicer.UnfreezeAsset,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.UnfreezeAssetContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            ),
            'UnfreezeAsset2': grpc.unary_unary_rpc_method_handler(
                    servicer.UnfreezeAsset2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.UnfreezeAssetContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'WithdrawBalance': grpc.unary_unary_rpc_method_handler(
                    servicer.WithdrawBalance,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.WithdrawBalanceContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            ),
            'WithdrawBalance2': grpc.unary_unary_rpc_method_handler(
                    servicer.WithdrawBalance2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.WithdrawBalanceContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'WithdrawExpireUnfreeze': grpc.unary_unary_rpc_method_handler(
                    servicer.WithdrawExpireUnfreeze,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.WithdrawExpireUnfreezeContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'DelegateResource': grpc.unary_unary_rpc_method_handler(
                    servicer.DelegateResource,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.DelegateResourceContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'UnDelegateResource': grpc.unary_unary_rpc_method_handler(
                    servicer.UnDelegateResource,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.UnDelegateResourceContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'CancelAllUnfreezeV2': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelAllUnfreezeV2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.CancelAllUnfreezeV2Contract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'UpdateAsset': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAsset,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.UpdateAssetContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            ),
            'UpdateAsset2': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAsset2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.UpdateAssetContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'ProposalCreate': grpc.unary_unary_rpc_method_handler(
                    servicer.ProposalCreate,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_proposal__contract__pb2.ProposalCreateContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'ProposalApprove': grpc.unary_unary_rpc_method_handler(
                    servicer.ProposalApprove,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_proposal__contract__pb2.ProposalApproveContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'ProposalDelete': grpc.unary_unary_rpc_method_handler(
                    servicer.ProposalDelete,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_proposal__contract__pb2.ProposalDeleteContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'BuyStorage': grpc.unary_unary_rpc_method_handler(
                    servicer.BuyStorage,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_storage__contract__pb2.BuyStorageContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'BuyStorageBytes': grpc.unary_unary_rpc_method_handler(
                    servicer.BuyStorageBytes,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_storage__contract__pb2.BuyStorageBytesContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'SellStorage': grpc.unary_unary_rpc_method_handler(
                    servicer.SellStorage,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_storage__contract__pb2.SellStorageContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'ExchangeCreate': grpc.unary_unary_rpc_method_handler(
                    servicer.ExchangeCreate,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_exchange__contract__pb2.ExchangeCreateContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'ExchangeInject': grpc.unary_unary_rpc_method_handler(
                    servicer.ExchangeInject,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_exchange__contract__pb2.ExchangeInjectContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'ExchangeWithdraw': grpc.unary_unary_rpc_method_handler(
                    servicer.ExchangeWithdraw,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_exchange__contract__pb2.ExchangeWithdrawContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'ExchangeTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.ExchangeTransaction,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_exchange__contract__pb2.ExchangeTransactionContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'MarketSellAsset': grpc.unary_unary_rpc_method_handler(
                    servicer.MarketSellAsset,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_market__contract__pb2.MarketSellAssetContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'MarketCancelOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.MarketCancelOrder,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_market__contract__pb2.MarketCancelOrderContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'GetMarketOrderById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMarketOrderById,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrder.SerializeToString,
            ),
            'GetMarketOrderByAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMarketOrderByAccount,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderList.SerializeToString,
            ),
            'GetMarketPriceByPair': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMarketPriceByPair,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderPair.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketPriceList.SerializeToString,
            ),
            'GetMarketOrderListByPair': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMarketOrderListByPair,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderPair.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderList.SerializeToString,
            ),
            'GetMarketPairList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMarketPairList,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderPairList.SerializeToString,
            ),
            'ListNodes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNodes,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NodeList.SerializeToString,
            ),
            'GetAssetIssueByAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAssetIssueByAccount,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AssetIssueList.SerializeToString,
            ),
            'GetAccountNet': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccountNet,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AccountNetMessage.SerializeToString,
            ),
            'GetAccountResource': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccountResource,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AccountResourceMessage.SerializeToString,
            ),
            'GetAssetIssueByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAssetIssueByName,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.AssetIssueContract.SerializeToString,
            ),
            'GetAssetIssueListByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAssetIssueListByName,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AssetIssueList.SerializeToString,
            ),
            'GetAssetIssueById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAssetIssueById,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.AssetIssueContract.SerializeToString,
            ),
            'GetNowBlock': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNowBlock,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Block.SerializeToString,
            ),
            'GetNowBlock2': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNowBlock2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockExtention.SerializeToString,
            ),
            'GetBlockByNum': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockByNum,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Block.SerializeToString,
            ),
            'GetBlockByNum2': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockByNum2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockExtention.SerializeToString,
            ),
            'GetTransactionCountByBlockNum': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionCountByBlockNum,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
            ),
            'GetBlockById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockById,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Block.SerializeToString,
            ),
            'GetBlockByLimitNext': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockByLimitNext,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockLimit.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockList.SerializeToString,
            ),
            'GetBlockByLimitNext2': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockByLimitNext2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockLimit.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockListExtention.SerializeToString,
            ),
            'GetBlockByLatestNum': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockByLatestNum,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockList.SerializeToString,
            ),
            'GetBlockByLatestNum2': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockByLatestNum2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockListExtention.SerializeToString,
            ),
            'GetTransactionById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionById,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            ),
            'DeployContract': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployContract,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.CreateSmartContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'GetContract': grpc.unary_unary_rpc_method_handler(
                    servicer.GetContract,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.SmartContract.SerializeToString,
            ),
            'GetContractInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetContractInfo,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.SmartContractDataWrapper.SerializeToString,
            ),
            'TriggerContract': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerContract,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.TriggerSmartContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'TriggerConstantContract': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerConstantContract,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.TriggerSmartContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'EstimateEnergy': grpc.unary_unary_rpc_method_handler(
                    servicer.EstimateEnergy,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.TriggerSmartContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EstimateEnergyMessage.SerializeToString,
            ),
            'ClearContractABI': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearContractABI,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.ClearABIContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'ListWitnesses': grpc.unary_unary_rpc_method_handler(
                    servicer.ListWitnesses,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.WitnessList.SerializeToString,
            ),
            'GetDelegatedResource': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDelegatedResource,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceList.SerializeToString,
            ),
            'GetDelegatedResourceV2': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDelegatedResourceV2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceList.SerializeToString,
            ),
            'GetDelegatedResourceAccountIndex': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDelegatedResourceAccountIndex,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.DelegatedResourceAccountIndex.SerializeToString,
            ),
            'GetDelegatedResourceAccountIndexV2': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDelegatedResourceAccountIndexV2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.DelegatedResourceAccountIndex.SerializeToString,
            ),
            'GetCanDelegatedMaxSize': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCanDelegatedMaxSize,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanDelegatedMaxSizeRequestMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanDelegatedMaxSizeResponseMessage.SerializeToString,
            ),
            'GetAvailableUnfreezeCount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAvailableUnfreezeCount,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.GetAvailableUnfreezeCountRequestMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.GetAvailableUnfreezeCountResponseMessage.SerializeToString,
            ),
            'GetCanWithdrawUnfreezeAmount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCanWithdrawUnfreezeAmount,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanWithdrawUnfreezeAmountRequestMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanWithdrawUnfreezeAmountResponseMessage.SerializeToString,
            ),
            'ListProposals': grpc.unary_unary_rpc_method_handler(
                    servicer.ListProposals,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ProposalList.SerializeToString,
            ),
            'GetPaginatedProposalList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPaginatedProposalList,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PaginatedMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ProposalList.SerializeToString,
            ),
            'GetProposalById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProposalById,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Proposal.SerializeToString,
            ),
            'ListExchanges': grpc.unary_unary_rpc_method_handler(
                    servicer.ListExchanges,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ExchangeList.SerializeToString,
            ),
            'GetPaginatedExchangeList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPaginatedExchangeList,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PaginatedMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ExchangeList.SerializeToString,
            ),
            'GetExchangeById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExchangeById,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Exchange.SerializeToString,
            ),
            'GetChainParameters': grpc.unary_unary_rpc_method_handler(
                    servicer.GetChainParameters,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.ChainParameters.SerializeToString,
            ),
            'GetAssetIssueList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAssetIssueList,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AssetIssueList.SerializeToString,
            ),
            'GetPaginatedAssetIssueList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPaginatedAssetIssueList,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PaginatedMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AssetIssueList.SerializeToString,
            ),
            'TotalTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.TotalTransaction,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
            ),
            'GetNextMaintenanceTime': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNextMaintenanceTime,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
            ),
            'GetTransactionInfoById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionInfoById,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.TransactionInfo.SerializeToString,
            ),
            'AccountPermissionUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.AccountPermissionUpdate,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_account__contract__pb2.AccountPermissionUpdateContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'GetTransactionSignWeight': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionSignWeight,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionSignWeight.SerializeToString,
            ),
            'GetTransactionApprovedList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionApprovedList,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionApprovedList.SerializeToString,
            ),
            'GetNodeInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNodeInfo,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.NodeInfo.SerializeToString,
            ),
            'GetRewardInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRewardInfo,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
            ),
            'GetBrokerageInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBrokerageInfo,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
            ),
            'UpdateBrokerage': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateBrokerage,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_storage__contract__pb2.UpdateBrokerageContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'CreateShieldedTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateShieldedTransaction,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PrivateParameters.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'GetMerkleTreeVoucherInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMerkleTreeVoucherInfo,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_shield__contract__pb2.OutputPointInfo.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_shield__contract__pb2.IncrementalMerkleVoucherInfo.SerializeToString,
            ),
            'ScanNoteByIvk': grpc.unary_unary_rpc_method_handler(
                    servicer.ScanNoteByIvk,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IvkDecryptParameters.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotes.SerializeToString,
            ),
            'ScanAndMarkNoteByIvk': grpc.unary_unary_rpc_method_handler(
                    servicer.ScanAndMarkNoteByIvk,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IvkDecryptAndMarkParameters.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotesMarked.SerializeToString,
            ),
            'ScanNoteByOvk': grpc.unary_unary_rpc_method_handler(
                    servicer.ScanNoteByOvk,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.OvkDecryptParameters.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotes.SerializeToString,
            ),
            'GetSpendingKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSpendingKey,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            ),
            'GetExpandedSpendingKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExpandedSpendingKey,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ExpandedSpendingKeyMessage.SerializeToString,
            ),
            'GetAkFromAsk': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAkFromAsk,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            ),
            'GetNkFromNsk': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNkFromNsk,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            ),
            'GetIncomingViewingKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIncomingViewingKey,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ViewingKeyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IncomingViewingKeyMessage.SerializeToString,
            ),
            'GetDiversifier': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDiversifier,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DiversifierMessage.SerializeToString,
            ),
            'GetNewShieldedAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNewShieldedAddress,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ShieldedAddressInfo.SerializeToString,
            ),
            'GetZenPaymentAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.GetZenPaymentAddress,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IncomingViewingKeyDiversifierMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PaymentAddressMessage.SerializeToString,
            ),
            'GetRcm': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRcm,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            ),
            'IsSpend': grpc.unary_unary_rpc_method_handler(
                    servicer.IsSpend,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NoteParameters.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.SpendResult.SerializeToString,
            ),
            'CreateShieldedTransactionWithoutSpendAuthSig': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateShieldedTransactionWithoutSpendAuthSig,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PrivateParametersWithoutAsk.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'GetShieldTransactionHash': grpc.unary_unary_rpc_method_handler(
                    servicer.GetShieldTransactionHash,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            ),
            'CreateSpendAuthSig': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSpendAuthSig,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.SpendAuthSigParameters.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            ),
            'CreateShieldNullifier': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateShieldNullifier,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NfParameters.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            ),
            'CreateShieldedContractParameters': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateShieldedContractParameters,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PrivateShieldedTRC20Parameters.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ShieldedTRC20Parameters.SerializeToString,
            ),
            'CreateShieldedContractParametersWithoutAsk': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateShieldedContractParametersWithoutAsk,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PrivateShieldedTRC20ParametersWithoutAsk.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ShieldedTRC20Parameters.SerializeToString,
            ),
            'ScanShieldedTRC20NotesByIvk': grpc.unary_unary_rpc_method_handler(
                    servicer.ScanShieldedTRC20NotesByIvk,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IvkDecryptTRC20Parameters.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotesTRC20.SerializeToString,
            ),
            'ScanShieldedTRC20NotesByOvk': grpc.unary_unary_rpc_method_handler(
                    servicer.ScanShieldedTRC20NotesByOvk,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.OvkDecryptTRC20Parameters.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotesTRC20.SerializeToString,
            ),
            'IsShieldedTRC20ContractNoteSpent': grpc.unary_unary_rpc_method_handler(
                    servicer.IsShieldedTRC20ContractNoteSpent,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NfTRC20Parameters.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NullifierResult.SerializeToString,
            ),
            'GetTriggerInputForShieldedTRC20Contract': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTriggerInputForShieldedTRC20Contract,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ShieldedTRC20TriggerContractParameters.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            ),
            'CreateCommonTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCommonTransaction,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'GetTransactionInfoByBlockNum': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionInfoByBlockNum,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionInfoList.SerializeToString,
            ),
            'GetBurnTrx': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBurnTrx,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
            ),
            'GetTransactionFromPending': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionFromPending,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            ),
            'GetTransactionListFromPending': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionListFromPending,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionIdList.SerializeToString,
            ),
            'GetPendingSize': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPendingSize,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
            ),
            'GetBlock': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlock,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockReq.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockExtention.SerializeToString,
            ),
            'GetBandwidthPrices': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBandwidthPrices,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PricesResponseMessage.SerializeToString,
            ),
            'GetEnergyPrices': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEnergyPrices,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PricesResponseMessage.SerializeToString,
            ),
            'GetMemoFee': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMemoFee,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PricesResponseMessage.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protocol.Wallet', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('protocol.Wallet', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Wallet(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetAccount',
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAccountById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetAccountById',
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAccountBalance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetAccountBalance',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.AccountBalanceRequest.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.AccountBalanceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBlockBalanceTrace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetBlockBalanceTrace',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.BlockBalanceTrace.BlockIdentifier.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.BlockBalanceTrace.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/CreateTransaction',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.TransferContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateTransaction2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/CreateTransaction2',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.TransferContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BroadcastTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/BroadcastTransaction',
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.Return.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/UpdateAccount',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_account__contract__pb2.AccountUpdateContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetAccountId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/SetAccountId',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_account__contract__pb2.SetAccountIdContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateAccount2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/UpdateAccount2',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_account__contract__pb2.AccountUpdateContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def VoteWitnessAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/VoteWitnessAccount',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_witness__contract__pb2.VoteWitnessContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateSetting(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/UpdateSetting',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.UpdateSettingContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateEnergyLimit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/UpdateEnergyLimit',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.UpdateEnergyLimitContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def VoteWitnessAccount2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/VoteWitnessAccount2',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_witness__contract__pb2.VoteWitnessContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateAssetIssue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/CreateAssetIssue',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.AssetIssueContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateAssetIssue2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/CreateAssetIssue2',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.AssetIssueContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateWitness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/UpdateWitness',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_witness__contract__pb2.WitnessUpdateContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateWitness2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/UpdateWitness2',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_witness__contract__pb2.WitnessUpdateContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/CreateAccount',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_account__contract__pb2.AccountCreateContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateAccount2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/CreateAccount2',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_account__contract__pb2.AccountCreateContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateWitness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/CreateWitness',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_witness__contract__pb2.WitnessCreateContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateWitness2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/CreateWitness2',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_witness__contract__pb2.WitnessCreateContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TransferAsset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/TransferAsset',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.TransferAssetContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TransferAsset2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/TransferAsset2',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.TransferAssetContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ParticipateAssetIssue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/ParticipateAssetIssue',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.ParticipateAssetIssueContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ParticipateAssetIssue2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/ParticipateAssetIssue2',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.ParticipateAssetIssueContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FreezeBalance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/FreezeBalance',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.FreezeBalanceContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FreezeBalance2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/FreezeBalance2',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.FreezeBalanceContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FreezeBalanceV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/FreezeBalanceV2',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.FreezeBalanceV2Contract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UnfreezeBalance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/UnfreezeBalance',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.UnfreezeBalanceContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UnfreezeBalance2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/UnfreezeBalance2',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.UnfreezeBalanceContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UnfreezeBalanceV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/UnfreezeBalanceV2',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.UnfreezeBalanceV2Contract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UnfreezeAsset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/UnfreezeAsset',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.UnfreezeAssetContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UnfreezeAsset2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/UnfreezeAsset2',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.UnfreezeAssetContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def WithdrawBalance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/WithdrawBalance',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.WithdrawBalanceContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def WithdrawBalance2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/WithdrawBalance2',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.WithdrawBalanceContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def WithdrawExpireUnfreeze(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/WithdrawExpireUnfreeze',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.WithdrawExpireUnfreezeContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DelegateResource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/DelegateResource',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.DelegateResourceContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UnDelegateResource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/UnDelegateResource',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.UnDelegateResourceContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CancelAllUnfreezeV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/CancelAllUnfreezeV2',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_balance__contract__pb2.CancelAllUnfreezeV2Contract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateAsset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/UpdateAsset',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.UpdateAssetContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateAsset2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/UpdateAsset2',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.UpdateAssetContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ProposalCreate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/ProposalCreate',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_proposal__contract__pb2.ProposalCreateContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ProposalApprove(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/ProposalApprove',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_proposal__contract__pb2.ProposalApproveContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ProposalDelete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/ProposalDelete',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_proposal__contract__pb2.ProposalDeleteContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BuyStorage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/BuyStorage',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_storage__contract__pb2.BuyStorageContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BuyStorageBytes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/BuyStorageBytes',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_storage__contract__pb2.BuyStorageBytesContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SellStorage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/SellStorage',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_storage__contract__pb2.SellStorageContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExchangeCreate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/ExchangeCreate',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_exchange__contract__pb2.ExchangeCreateContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExchangeInject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/ExchangeInject',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_exchange__contract__pb2.ExchangeInjectContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExchangeWithdraw(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/ExchangeWithdraw',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_exchange__contract__pb2.ExchangeWithdrawContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExchangeTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/ExchangeTransaction',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_exchange__contract__pb2.ExchangeTransactionContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MarketSellAsset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/MarketSellAsset',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_market__contract__pb2.MarketSellAssetContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MarketCancelOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/MarketCancelOrder',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_market__contract__pb2.MarketCancelOrderContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetMarketOrderById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetMarketOrderById',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrder.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetMarketOrderByAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetMarketOrderByAccount',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetMarketPriceByPair(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetMarketPriceByPair',
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderPair.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketPriceList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetMarketOrderListByPair(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetMarketOrderListByPair',
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderPair.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetMarketPairList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetMarketPairList',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderPairList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListNodes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/ListNodes',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NodeList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAssetIssueByAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetAssetIssueByAccount',
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AssetIssueList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAccountNet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetAccountNet',
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AccountNetMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAccountResource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetAccountResource',
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AccountResourceMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAssetIssueByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetAssetIssueByName',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.AssetIssueContract.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAssetIssueListByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetAssetIssueListByName',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AssetIssueList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAssetIssueById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetAssetIssueById',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.AssetIssueContract.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetNowBlock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetNowBlock',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Block.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetNowBlock2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetNowBlock2',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBlockByNum(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetBlockByNum',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Block.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBlockByNum2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetBlockByNum2',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTransactionCountByBlockNum(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetTransactionCountByBlockNum',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBlockById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetBlockById',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Block.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBlockByLimitNext(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetBlockByLimitNext',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockLimit.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBlockByLimitNext2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetBlockByLimitNext2',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockLimit.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockListExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBlockByLatestNum(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetBlockByLatestNum',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBlockByLatestNum2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetBlockByLatestNum2',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockListExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTransactionById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetTransactionById',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeployContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/DeployContract',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.CreateSmartContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetContract',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.SmartContract.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetContractInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetContractInfo',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.SmartContractDataWrapper.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TriggerContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/TriggerContract',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.TriggerSmartContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TriggerConstantContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/TriggerConstantContract',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.TriggerSmartContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def EstimateEnergy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/EstimateEnergy',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.TriggerSmartContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EstimateEnergyMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ClearContractABI(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/ClearContractABI',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.ClearABIContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListWitnesses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/ListWitnesses',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.WitnessList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDelegatedResource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetDelegatedResource',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDelegatedResourceV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetDelegatedResourceV2',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDelegatedResourceAccountIndex(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetDelegatedResourceAccountIndex',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.DelegatedResourceAccountIndex.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDelegatedResourceAccountIndexV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetDelegatedResourceAccountIndexV2',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.DelegatedResourceAccountIndex.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCanDelegatedMaxSize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetCanDelegatedMaxSize',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanDelegatedMaxSizeRequestMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanDelegatedMaxSizeResponseMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAvailableUnfreezeCount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetAvailableUnfreezeCount',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.GetAvailableUnfreezeCountRequestMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.GetAvailableUnfreezeCountResponseMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCanWithdrawUnfreezeAmount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetCanWithdrawUnfreezeAmount',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanWithdrawUnfreezeAmountRequestMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanWithdrawUnfreezeAmountResponseMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListProposals(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/ListProposals',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ProposalList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPaginatedProposalList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetPaginatedProposalList',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PaginatedMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ProposalList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetProposalById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetProposalById',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Proposal.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListExchanges(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/ListExchanges',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ExchangeList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPaginatedExchangeList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetPaginatedExchangeList',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PaginatedMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ExchangeList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetExchangeById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetExchangeById',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Exchange.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetChainParameters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetChainParameters',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.ChainParameters.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAssetIssueList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetAssetIssueList',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AssetIssueList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPaginatedAssetIssueList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetPaginatedAssetIssueList',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PaginatedMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AssetIssueList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TotalTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/TotalTransaction',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetNextMaintenanceTime(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetNextMaintenanceTime',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTransactionInfoById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetTransactionInfoById',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.TransactionInfo.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AccountPermissionUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/AccountPermissionUpdate',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_account__contract__pb2.AccountPermissionUpdateContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTransactionSignWeight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetTransactionSignWeight',
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionSignWeight.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTransactionApprovedList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetTransactionApprovedList',
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionApprovedList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetNodeInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetNodeInfo',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.NodeInfo.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetRewardInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetRewardInfo',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBrokerageInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetBrokerageInfo',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateBrokerage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/UpdateBrokerage',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_storage__contract__pb2.UpdateBrokerageContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateShieldedTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/CreateShieldedTransaction',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PrivateParameters.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetMerkleTreeVoucherInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetMerkleTreeVoucherInfo',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_shield__contract__pb2.OutputPointInfo.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_shield__contract__pb2.IncrementalMerkleVoucherInfo.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ScanNoteByIvk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/ScanNoteByIvk',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IvkDecryptParameters.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotes.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ScanAndMarkNoteByIvk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/ScanAndMarkNoteByIvk',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IvkDecryptAndMarkParameters.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotesMarked.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ScanNoteByOvk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/ScanNoteByOvk',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.OvkDecryptParameters.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotes.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSpendingKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetSpendingKey',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetExpandedSpendingKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetExpandedSpendingKey',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ExpandedSpendingKeyMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAkFromAsk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetAkFromAsk',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetNkFromNsk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetNkFromNsk',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetIncomingViewingKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetIncomingViewingKey',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ViewingKeyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IncomingViewingKeyMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDiversifier(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetDiversifier',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DiversifierMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetNewShieldedAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetNewShieldedAddress',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ShieldedAddressInfo.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetZenPaymentAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetZenPaymentAddress',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IncomingViewingKeyDiversifierMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PaymentAddressMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetRcm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetRcm',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IsSpend(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/IsSpend',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NoteParameters.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.SpendResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateShieldedTransactionWithoutSpendAuthSig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/CreateShieldedTransactionWithoutSpendAuthSig',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PrivateParametersWithoutAsk.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetShieldTransactionHash(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetShieldTransactionHash',
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateSpendAuthSig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/CreateSpendAuthSig',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.SpendAuthSigParameters.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateShieldNullifier(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/CreateShieldNullifier',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NfParameters.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateShieldedContractParameters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/CreateShieldedContractParameters',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PrivateShieldedTRC20Parameters.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ShieldedTRC20Parameters.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateShieldedContractParametersWithoutAsk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/CreateShieldedContractParametersWithoutAsk',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PrivateShieldedTRC20ParametersWithoutAsk.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ShieldedTRC20Parameters.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ScanShieldedTRC20NotesByIvk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/ScanShieldedTRC20NotesByIvk',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IvkDecryptTRC20Parameters.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotesTRC20.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ScanShieldedTRC20NotesByOvk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/ScanShieldedTRC20NotesByOvk',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.OvkDecryptTRC20Parameters.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotesTRC20.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IsShieldedTRC20ContractNoteSpent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/IsShieldedTRC20ContractNoteSpent',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NfTRC20Parameters.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NullifierResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTriggerInputForShieldedTRC20Contract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetTriggerInputForShieldedTRC20Contract',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ShieldedTRC20TriggerContractParameters.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateCommonTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/CreateCommonTransaction',
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTransactionInfoByBlockNum(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetTransactionInfoByBlockNum',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionInfoList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBurnTrx(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetBurnTrx',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTransactionFromPending(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetTransactionFromPending',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTransactionListFromPending(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetTransactionListFromPending',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionIdList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPendingSize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetPendingSize',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBlock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetBlock',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockReq.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBandwidthPrices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetBandwidthPrices',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PricesResponseMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetEnergyPrices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetEnergyPrices',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PricesResponseMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetMemoFee(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Wallet/GetMemoFee',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PricesResponseMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class WalletSolidityStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAccount = channel.unary_unary(
                '/protocol.WalletSolidity/GetAccount',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.FromString,
                _registered_method=True)
        self.GetAccountById = channel.unary_unary(
                '/protocol.WalletSolidity/GetAccountById',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.FromString,
                _registered_method=True)
        self.ListWitnesses = channel.unary_unary(
                '/protocol.WalletSolidity/ListWitnesses',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.WitnessList.FromString,
                _registered_method=True)
        self.GetAssetIssueList = channel.unary_unary(
                '/protocol.WalletSolidity/GetAssetIssueList',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AssetIssueList.FromString,
                _registered_method=True)
        self.GetPaginatedAssetIssueList = channel.unary_unary(
                '/protocol.WalletSolidity/GetPaginatedAssetIssueList',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PaginatedMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AssetIssueList.FromString,
                _registered_method=True)
        self.GetAssetIssueByName = channel.unary_unary(
                '/protocol.WalletSolidity/GetAssetIssueByName',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.AssetIssueContract.FromString,
                _registered_method=True)
        self.GetAssetIssueListByName = channel.unary_unary(
                '/protocol.WalletSolidity/GetAssetIssueListByName',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AssetIssueList.FromString,
                _registered_method=True)
        self.GetAssetIssueById = channel.unary_unary(
                '/protocol.WalletSolidity/GetAssetIssueById',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.AssetIssueContract.FromString,
                _registered_method=True)
        self.GetNowBlock = channel.unary_unary(
                '/protocol.WalletSolidity/GetNowBlock',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Block.FromString,
                _registered_method=True)
        self.GetNowBlock2 = channel.unary_unary(
                '/protocol.WalletSolidity/GetNowBlock2',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockExtention.FromString,
                _registered_method=True)
        self.GetBlockByNum = channel.unary_unary(
                '/protocol.WalletSolidity/GetBlockByNum',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Block.FromString,
                _registered_method=True)
        self.GetBlockByNum2 = channel.unary_unary(
                '/protocol.WalletSolidity/GetBlockByNum2',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockExtention.FromString,
                _registered_method=True)
        self.GetTransactionCountByBlockNum = channel.unary_unary(
                '/protocol.WalletSolidity/GetTransactionCountByBlockNum',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
                _registered_method=True)
        self.GetDelegatedResource = channel.unary_unary(
                '/protocol.WalletSolidity/GetDelegatedResource',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceList.FromString,
                _registered_method=True)
        self.GetDelegatedResourceV2 = channel.unary_unary(
                '/protocol.WalletSolidity/GetDelegatedResourceV2',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceList.FromString,
                _registered_method=True)
        self.GetDelegatedResourceAccountIndex = channel.unary_unary(
                '/protocol.WalletSolidity/GetDelegatedResourceAccountIndex',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.DelegatedResourceAccountIndex.FromString,
                _registered_method=True)
        self.GetDelegatedResourceAccountIndexV2 = channel.unary_unary(
                '/protocol.WalletSolidity/GetDelegatedResourceAccountIndexV2',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.DelegatedResourceAccountIndex.FromString,
                _registered_method=True)
        self.GetCanDelegatedMaxSize = channel.unary_unary(
                '/protocol.WalletSolidity/GetCanDelegatedMaxSize',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanDelegatedMaxSizeRequestMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanDelegatedMaxSizeResponseMessage.FromString,
                _registered_method=True)
        self.GetAvailableUnfreezeCount = channel.unary_unary(
                '/protocol.WalletSolidity/GetAvailableUnfreezeCount',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.GetAvailableUnfreezeCountRequestMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.GetAvailableUnfreezeCountResponseMessage.FromString,
                _registered_method=True)
        self.GetCanWithdrawUnfreezeAmount = channel.unary_unary(
                '/protocol.WalletSolidity/GetCanWithdrawUnfreezeAmount',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanWithdrawUnfreezeAmountRequestMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanWithdrawUnfreezeAmountResponseMessage.FromString,
                _registered_method=True)
        self.GetExchangeById = channel.unary_unary(
                '/protocol.WalletSolidity/GetExchangeById',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Exchange.FromString,
                _registered_method=True)
        self.ListExchanges = channel.unary_unary(
                '/protocol.WalletSolidity/ListExchanges',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ExchangeList.FromString,
                _registered_method=True)
        self.GetTransactionById = channel.unary_unary(
                '/protocol.WalletSolidity/GetTransactionById',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
                _registered_method=True)
        self.GetTransactionInfoById = channel.unary_unary(
                '/protocol.WalletSolidity/GetTransactionInfoById',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.TransactionInfo.FromString,
                _registered_method=True)
        self.GetMerkleTreeVoucherInfo = channel.unary_unary(
                '/protocol.WalletSolidity/GetMerkleTreeVoucherInfo',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_shield__contract__pb2.OutputPointInfo.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_shield__contract__pb2.IncrementalMerkleVoucherInfo.FromString,
                _registered_method=True)
        self.ScanNoteByIvk = channel.unary_unary(
                '/protocol.WalletSolidity/ScanNoteByIvk',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IvkDecryptParameters.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotes.FromString,
                _registered_method=True)
        self.ScanAndMarkNoteByIvk = channel.unary_unary(
                '/protocol.WalletSolidity/ScanAndMarkNoteByIvk',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IvkDecryptAndMarkParameters.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotesMarked.FromString,
                _registered_method=True)
        self.ScanNoteByOvk = channel.unary_unary(
                '/protocol.WalletSolidity/ScanNoteByOvk',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.OvkDecryptParameters.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotes.FromString,
                _registered_method=True)
        self.IsSpend = channel.unary_unary(
                '/protocol.WalletSolidity/IsSpend',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NoteParameters.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.SpendResult.FromString,
                _registered_method=True)
        self.ScanShieldedTRC20NotesByIvk = channel.unary_unary(
                '/protocol.WalletSolidity/ScanShieldedTRC20NotesByIvk',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IvkDecryptTRC20Parameters.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotesTRC20.FromString,
                _registered_method=True)
        self.ScanShieldedTRC20NotesByOvk = channel.unary_unary(
                '/protocol.WalletSolidity/ScanShieldedTRC20NotesByOvk',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.OvkDecryptTRC20Parameters.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotesTRC20.FromString,
                _registered_method=True)
        self.IsShieldedTRC20ContractNoteSpent = channel.unary_unary(
                '/protocol.WalletSolidity/IsShieldedTRC20ContractNoteSpent',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NfTRC20Parameters.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NullifierResult.FromString,
                _registered_method=True)
        self.GetRewardInfo = channel.unary_unary(
                '/protocol.WalletSolidity/GetRewardInfo',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
                _registered_method=True)
        self.GetBrokerageInfo = channel.unary_unary(
                '/protocol.WalletSolidity/GetBrokerageInfo',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
                _registered_method=True)
        self.TriggerConstantContract = channel.unary_unary(
                '/protocol.WalletSolidity/TriggerConstantContract',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.TriggerSmartContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
                _registered_method=True)
        self.EstimateEnergy = channel.unary_unary(
                '/protocol.WalletSolidity/EstimateEnergy',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.TriggerSmartContract.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EstimateEnergyMessage.FromString,
                _registered_method=True)
        self.GetTransactionInfoByBlockNum = channel.unary_unary(
                '/protocol.WalletSolidity/GetTransactionInfoByBlockNum',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionInfoList.FromString,
                _registered_method=True)
        self.GetMarketOrderById = channel.unary_unary(
                '/protocol.WalletSolidity/GetMarketOrderById',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrder.FromString,
                _registered_method=True)
        self.GetMarketOrderByAccount = channel.unary_unary(
                '/protocol.WalletSolidity/GetMarketOrderByAccount',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderList.FromString,
                _registered_method=True)
        self.GetMarketPriceByPair = channel.unary_unary(
                '/protocol.WalletSolidity/GetMarketPriceByPair',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderPair.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketPriceList.FromString,
                _registered_method=True)
        self.GetMarketOrderListByPair = channel.unary_unary(
                '/protocol.WalletSolidity/GetMarketOrderListByPair',
                request_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderPair.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderList.FromString,
                _registered_method=True)
        self.GetMarketPairList = channel.unary_unary(
                '/protocol.WalletSolidity/GetMarketPairList',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderPairList.FromString,
                _registered_method=True)
        self.GetBurnTrx = channel.unary_unary(
                '/protocol.WalletSolidity/GetBurnTrx',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
                _registered_method=True)
        self.GetBlock = channel.unary_unary(
                '/protocol.WalletSolidity/GetBlock',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockReq.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockExtention.FromString,
                _registered_method=True)
        self.GetBandwidthPrices = channel.unary_unary(
                '/protocol.WalletSolidity/GetBandwidthPrices',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PricesResponseMessage.FromString,
                _registered_method=True)
        self.GetEnergyPrices = channel.unary_unary(
                '/protocol.WalletSolidity/GetEnergyPrices',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PricesResponseMessage.FromString,
                _registered_method=True)


class WalletSolidityServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccountById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListWitnesses(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAssetIssueList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPaginatedAssetIssueList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAssetIssueByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAssetIssueListByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAssetIssueById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNowBlock(self, request, context):
        """Please use GetNowBlock2 instead of this function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNowBlock2(self, request, context):
        """Use this function instead of GetNowBlock.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockByNum(self, request, context):
        """Please use GetBlockByNum2 instead of this function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockByNum2(self, request, context):
        """Use this function instead of GetBlockByNum.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionCountByBlockNum(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDelegatedResource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDelegatedResourceV2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDelegatedResourceAccountIndex(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDelegatedResourceAccountIndexV2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCanDelegatedMaxSize(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAvailableUnfreezeCount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCanWithdrawUnfreezeAmount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExchangeById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListExchanges(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionInfoById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMerkleTreeVoucherInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScanNoteByIvk(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScanAndMarkNoteByIvk(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScanNoteByOvk(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsSpend(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScanShieldedTRC20NotesByIvk(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScanShieldedTRC20NotesByOvk(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsShieldedTRC20ContractNoteSpent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRewardInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBrokerageInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerConstantContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EstimateEnergy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionInfoByBlockNum(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMarketOrderById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMarketOrderByAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMarketPriceByPair(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMarketOrderListByPair(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMarketPairList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBurnTrx(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlock(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBandwidthPrices(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEnergyPrices(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WalletSolidityServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccount,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.SerializeToString,
            ),
            'GetAccountById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccountById,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.SerializeToString,
            ),
            'ListWitnesses': grpc.unary_unary_rpc_method_handler(
                    servicer.ListWitnesses,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.WitnessList.SerializeToString,
            ),
            'GetAssetIssueList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAssetIssueList,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AssetIssueList.SerializeToString,
            ),
            'GetPaginatedAssetIssueList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPaginatedAssetIssueList,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PaginatedMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AssetIssueList.SerializeToString,
            ),
            'GetAssetIssueByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAssetIssueByName,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.AssetIssueContract.SerializeToString,
            ),
            'GetAssetIssueListByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAssetIssueListByName,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AssetIssueList.SerializeToString,
            ),
            'GetAssetIssueById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAssetIssueById,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.AssetIssueContract.SerializeToString,
            ),
            'GetNowBlock': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNowBlock,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Block.SerializeToString,
            ),
            'GetNowBlock2': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNowBlock2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockExtention.SerializeToString,
            ),
            'GetBlockByNum': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockByNum,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Block.SerializeToString,
            ),
            'GetBlockByNum2': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockByNum2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockExtention.SerializeToString,
            ),
            'GetTransactionCountByBlockNum': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionCountByBlockNum,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
            ),
            'GetDelegatedResource': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDelegatedResource,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceList.SerializeToString,
            ),
            'GetDelegatedResourceV2': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDelegatedResourceV2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceList.SerializeToString,
            ),
            'GetDelegatedResourceAccountIndex': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDelegatedResourceAccountIndex,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.DelegatedResourceAccountIndex.SerializeToString,
            ),
            'GetDelegatedResourceAccountIndexV2': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDelegatedResourceAccountIndexV2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.DelegatedResourceAccountIndex.SerializeToString,
            ),
            'GetCanDelegatedMaxSize': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCanDelegatedMaxSize,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanDelegatedMaxSizeRequestMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanDelegatedMaxSizeResponseMessage.SerializeToString,
            ),
            'GetAvailableUnfreezeCount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAvailableUnfreezeCount,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.GetAvailableUnfreezeCountRequestMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.GetAvailableUnfreezeCountResponseMessage.SerializeToString,
            ),
            'GetCanWithdrawUnfreezeAmount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCanWithdrawUnfreezeAmount,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanWithdrawUnfreezeAmountRequestMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanWithdrawUnfreezeAmountResponseMessage.SerializeToString,
            ),
            'GetExchangeById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExchangeById,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Exchange.SerializeToString,
            ),
            'ListExchanges': grpc.unary_unary_rpc_method_handler(
                    servicer.ListExchanges,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ExchangeList.SerializeToString,
            ),
            'GetTransactionById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionById,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.SerializeToString,
            ),
            'GetTransactionInfoById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionInfoById,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.TransactionInfo.SerializeToString,
            ),
            'GetMerkleTreeVoucherInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMerkleTreeVoucherInfo,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_shield__contract__pb2.OutputPointInfo.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_shield__contract__pb2.IncrementalMerkleVoucherInfo.SerializeToString,
            ),
            'ScanNoteByIvk': grpc.unary_unary_rpc_method_handler(
                    servicer.ScanNoteByIvk,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IvkDecryptParameters.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotes.SerializeToString,
            ),
            'ScanAndMarkNoteByIvk': grpc.unary_unary_rpc_method_handler(
                    servicer.ScanAndMarkNoteByIvk,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IvkDecryptAndMarkParameters.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotesMarked.SerializeToString,
            ),
            'ScanNoteByOvk': grpc.unary_unary_rpc_method_handler(
                    servicer.ScanNoteByOvk,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.OvkDecryptParameters.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotes.SerializeToString,
            ),
            'IsSpend': grpc.unary_unary_rpc_method_handler(
                    servicer.IsSpend,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NoteParameters.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.SpendResult.SerializeToString,
            ),
            'ScanShieldedTRC20NotesByIvk': grpc.unary_unary_rpc_method_handler(
                    servicer.ScanShieldedTRC20NotesByIvk,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IvkDecryptTRC20Parameters.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotesTRC20.SerializeToString,
            ),
            'ScanShieldedTRC20NotesByOvk': grpc.unary_unary_rpc_method_handler(
                    servicer.ScanShieldedTRC20NotesByOvk,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.OvkDecryptTRC20Parameters.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotesTRC20.SerializeToString,
            ),
            'IsShieldedTRC20ContractNoteSpent': grpc.unary_unary_rpc_method_handler(
                    servicer.IsShieldedTRC20ContractNoteSpent,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NfTRC20Parameters.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NullifierResult.SerializeToString,
            ),
            'GetRewardInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRewardInfo,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
            ),
            'GetBrokerageInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBrokerageInfo,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
            ),
            'TriggerConstantContract': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerConstantContract,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.TriggerSmartContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.SerializeToString,
            ),
            'EstimateEnergy': grpc.unary_unary_rpc_method_handler(
                    servicer.EstimateEnergy,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.TriggerSmartContract.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EstimateEnergyMessage.SerializeToString,
            ),
            'GetTransactionInfoByBlockNum': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionInfoByBlockNum,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionInfoList.SerializeToString,
            ),
            'GetMarketOrderById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMarketOrderById,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrder.SerializeToString,
            ),
            'GetMarketOrderByAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMarketOrderByAccount,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderList.SerializeToString,
            ),
            'GetMarketPriceByPair': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMarketPriceByPair,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderPair.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketPriceList.SerializeToString,
            ),
            'GetMarketOrderListByPair': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMarketOrderListByPair,
                    request_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderPair.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderList.SerializeToString,
            ),
            'GetMarketPairList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMarketPairList,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderPairList.SerializeToString,
            ),
            'GetBurnTrx': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBurnTrx,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
            ),
            'GetBlock': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlock,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockReq.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockExtention.SerializeToString,
            ),
            'GetBandwidthPrices': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBandwidthPrices,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PricesResponseMessage.SerializeToString,
            ),
            'GetEnergyPrices': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEnergyPrices,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PricesResponseMessage.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protocol.WalletSolidity', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('protocol.WalletSolidity', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class WalletSolidity(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetAccount',
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAccountById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetAccountById',
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Account.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListWitnesses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/ListWitnesses',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.WitnessList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAssetIssueList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetAssetIssueList',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AssetIssueList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPaginatedAssetIssueList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetPaginatedAssetIssueList',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PaginatedMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AssetIssueList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAssetIssueByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetAssetIssueByName',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.AssetIssueContract.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAssetIssueListByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetAssetIssueListByName',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AssetIssueList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAssetIssueById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetAssetIssueById',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_asset__issue__contract__pb2.AssetIssueContract.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetNowBlock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetNowBlock',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Block.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetNowBlock2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetNowBlock2',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBlockByNum(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetBlockByNum',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Block.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBlockByNum2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetBlockByNum2',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTransactionCountByBlockNum(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetTransactionCountByBlockNum',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDelegatedResource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetDelegatedResource',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDelegatedResourceV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetDelegatedResourceV2',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DelegatedResourceList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDelegatedResourceAccountIndex(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetDelegatedResourceAccountIndex',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.DelegatedResourceAccountIndex.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDelegatedResourceAccountIndexV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetDelegatedResourceAccountIndexV2',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.DelegatedResourceAccountIndex.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCanDelegatedMaxSize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetCanDelegatedMaxSize',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanDelegatedMaxSizeRequestMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanDelegatedMaxSizeResponseMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAvailableUnfreezeCount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetAvailableUnfreezeCount',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.GetAvailableUnfreezeCountRequestMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.GetAvailableUnfreezeCountResponseMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCanWithdrawUnfreezeAmount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetCanWithdrawUnfreezeAmount',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanWithdrawUnfreezeAmountRequestMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.CanWithdrawUnfreezeAmountResponseMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetExchangeById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetExchangeById',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Exchange.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListExchanges(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/ListExchanges',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.ExchangeList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTransactionById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetTransactionById',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Transaction.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTransactionInfoById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetTransactionInfoById',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.TransactionInfo.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetMerkleTreeVoucherInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetMerkleTreeVoucherInfo',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_shield__contract__pb2.OutputPointInfo.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_shield__contract__pb2.IncrementalMerkleVoucherInfo.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ScanNoteByIvk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/ScanNoteByIvk',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IvkDecryptParameters.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotes.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ScanAndMarkNoteByIvk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/ScanAndMarkNoteByIvk',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IvkDecryptAndMarkParameters.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotesMarked.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ScanNoteByOvk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/ScanNoteByOvk',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.OvkDecryptParameters.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotes.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IsSpend(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/IsSpend',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NoteParameters.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.SpendResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ScanShieldedTRC20NotesByIvk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/ScanShieldedTRC20NotesByIvk',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.IvkDecryptTRC20Parameters.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotesTRC20.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ScanShieldedTRC20NotesByOvk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/ScanShieldedTRC20NotesByOvk',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.OvkDecryptTRC20Parameters.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.DecryptNotesTRC20.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IsShieldedTRC20ContractNoteSpent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/IsShieldedTRC20ContractNoteSpent',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NfTRC20Parameters.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NullifierResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetRewardInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetRewardInfo',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBrokerageInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetBrokerageInfo',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TriggerConstantContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/TriggerConstantContract',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.TriggerSmartContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def EstimateEnergy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/EstimateEnergy',
            tron__sdk__py_dot_proto_dot_core_dot_contract_dot_smart__contract__pb2.TriggerSmartContract.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EstimateEnergyMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTransactionInfoByBlockNum(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetTransactionInfoByBlockNum',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionInfoList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetMarketOrderById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetMarketOrderById',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrder.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetMarketOrderByAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetMarketOrderByAccount',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BytesMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetMarketPriceByPair(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetMarketPriceByPair',
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderPair.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketPriceList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetMarketOrderListByPair(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetMarketOrderListByPair',
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderPair.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetMarketPairList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetMarketPairList',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MarketOrderPairList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBurnTrx(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetBurnTrx',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBlock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetBlock',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockReq.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBandwidthPrices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetBandwidthPrices',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PricesResponseMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetEnergyPrices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletSolidity/GetEnergyPrices',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.PricesResponseMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class WalletExtensionStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetTransactionsFromThis = channel.unary_unary(
                '/protocol.WalletExtension/GetTransactionsFromThis',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AccountPaginated.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionList.FromString,
                _registered_method=True)
        self.GetTransactionsFromThis2 = channel.unary_unary(
                '/protocol.WalletExtension/GetTransactionsFromThis2',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AccountPaginated.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionListExtention.FromString,
                _registered_method=True)
        self.GetTransactionsToThis = channel.unary_unary(
                '/protocol.WalletExtension/GetTransactionsToThis',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AccountPaginated.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionList.FromString,
                _registered_method=True)
        self.GetTransactionsToThis2 = channel.unary_unary(
                '/protocol.WalletExtension/GetTransactionsToThis2',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AccountPaginated.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionListExtention.FromString,
                _registered_method=True)


class WalletExtensionServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetTransactionsFromThis(self, request, context):
        """Please use GetTransactionsFromThis2 instead of this function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionsFromThis2(self, request, context):
        """Use this function instead of GetTransactionsFromThis.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionsToThis(self, request, context):
        """Please use GetTransactionsToThis2 instead of this function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionsToThis2(self, request, context):
        """Use this function instead of GetTransactionsToThis.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WalletExtensionServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetTransactionsFromThis': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionsFromThis,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AccountPaginated.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionList.SerializeToString,
            ),
            'GetTransactionsFromThis2': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionsFromThis2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AccountPaginated.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionListExtention.SerializeToString,
            ),
            'GetTransactionsToThis': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionsToThis,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AccountPaginated.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionList.SerializeToString,
            ),
            'GetTransactionsToThis2': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionsToThis2,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AccountPaginated.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionListExtention.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protocol.WalletExtension', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('protocol.WalletExtension', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class WalletExtension(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetTransactionsFromThis(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletExtension/GetTransactionsFromThis',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AccountPaginated.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTransactionsFromThis2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletExtension/GetTransactionsFromThis2',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AccountPaginated.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionListExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTransactionsToThis(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletExtension/GetTransactionsToThis',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AccountPaginated.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTransactionsToThis2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.WalletExtension/GetTransactionsToThis2',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.AccountPaginated.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.TransactionListExtention.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class DatabaseStub(object):
    """the api of tron's db
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.getBlockReference = channel.unary_unary(
                '/protocol.Database/getBlockReference',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockReference.FromString,
                _registered_method=True)
        self.GetDynamicProperties = channel.unary_unary(
                '/protocol.Database/GetDynamicProperties',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.DynamicProperties.FromString,
                _registered_method=True)
        self.GetNowBlock = channel.unary_unary(
                '/protocol.Database/GetNowBlock',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Block.FromString,
                _registered_method=True)
        self.GetBlockByNum = channel.unary_unary(
                '/protocol.Database/GetBlockByNum',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Block.FromString,
                _registered_method=True)


class DatabaseServicer(object):
    """the api of tron's db
    """

    def getBlockReference(self, request, context):
        """for tapos
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDynamicProperties(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNowBlock(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockByNum(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DatabaseServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'getBlockReference': grpc.unary_unary_rpc_method_handler(
                    servicer.getBlockReference,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockReference.SerializeToString,
            ),
            'GetDynamicProperties': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDynamicProperties,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.DynamicProperties.SerializeToString,
            ),
            'GetNowBlock': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNowBlock,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Block.SerializeToString,
            ),
            'GetBlockByNum': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockByNum,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Block.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protocol.Database', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('protocol.Database', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Database(object):
    """the api of tron's db
    """

    @staticmethod
    def getBlockReference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Database/getBlockReference',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.BlockReference.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDynamicProperties(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Database/GetDynamicProperties',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.DynamicProperties.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetNowBlock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Database/GetNowBlock',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Block.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBlockByNum(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Database/GetBlockByNum',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.NumberMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.Block.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class MonitorStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetStatsInfo = channel.unary_unary(
                '/protocol.Monitor/GetStatsInfo',
                request_serializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MetricsInfo.FromString,
                _registered_method=True)


class MonitorServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetStatsInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MonitorServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetStatsInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStatsInfo,
                    request_deserializer=tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.FromString,
                    response_serializer=tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MetricsInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protocol.Monitor', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('protocol.Monitor', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Monitor(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetStatsInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocol.Monitor/GetStatsInfo',
            tron__sdk__py_dot_proto_dot_api_dot_api__pb2.EmptyMessage.SerializeToString,
            tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2.MetricsInfo.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class NetworkStub(object):
    """the api of tron's network such as node list.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """


class NetworkServicer(object):
    """the api of tron's network such as node list.
    """


def add_NetworkServicer_to_server(servicer, server):
    rpc_method_handlers = {
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protocol.Network', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('protocol.Network', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Network(object):
    """the api of tron's network such as node list.
    """
